@@ -15,7 +15,9 @@ use OCP\Activity\IEvent;
 use OCP\Activity\IExtension;
 use OCP\Activity\IFilter;
 use OCP\Activity\IManager;
+use OCP\DB\Exception;
 use OCP\DB\QueryBuilder\IQueryBuilder;
+use OCP\IConfig;
 use OCP\IDBConnection;
 use Psr\Log\LoggerInterface;
 
@@ -31,7 +33,9 @@ class Data {
 	public function __construct(
 		protected IManager $activityManager,
 		protected IDBConnection $connection,
-		protected LoggerInterface $logger) {
+		protected LoggerInterface $logger,
+		protected IConfig $config,
+	) {
 	}
 
 	/**
@@ -88,6 +92,75 @@ class Data {
 		return $this->insertActivity->getLastInsertId();
 	}
 
+	/**
+	 * Bulk sends an event into the activity stream
+	 * for a batch of users that are affected by the same event
+	 * (ex. Call Started, Call ended)
+	 *
+	 * @param IEvent $event
+	 * @param array $affectedUsers
+	 * @return array<int, string>
+	 * @throws Exception
+	 */
+	public function bulkSend(IEvent $event, array $affectedUsers): array {
+		$this->connection->beginTransaction();
+
+		$activityIds = [];
+		try {
+			if ($this->insertActivity === null) {
+				$this->insertActivity = $this->connection->getQueryBuilder();
+			}
+			$this->insertActivity->insert('activity')
+				->values([
+					'app' => $this->insertActivity->createParameter('app'),
+					'subject' => $this->insertActivity->createParameter('subject'),
+					'subjectparams' => $this->insertActivity->createParameter('subjectparams'),
+					'message' => $this->insertActivity->createParameter('message'),
+					'messageparams' => $this->insertActivity->createParameter('messageparams'),
+					'file' => $this->insertActivity->createParameter('object_name'),
+					'link' => $this->insertActivity->createParameter('link'),
+					'user' => $this->insertActivity->createParameter('user'),
+					'affecteduser' => $this->insertActivity->createParameter('affecteduser'),
+					'timestamp' => $this->insertActivity->createParameter('timestamp'),
+					'priority' => $this->insertActivity->createParameter('priority'),
+					'type' => $this->insertActivity->createParameter('type'),
+					'object_type' => $this->insertActivity->createParameter('object_type'),
+					'object_id' => $this->insertActivity->createParameter('object_id'),
+				]);
+
+			$this->insertActivity->setParameters([
+				'app' => $event->getApp(),
+				'type' => $event->getType(),
+				'user' => $event->getAuthor(),
+				'timestamp' => $event->getTimestamp(),
+				'subject' => $event->getSubject(),
+				'subjectparams' => json_encode($event->getSubjectParameters()),
+				'message' => $event->getMessage(),
+				'messageparams' => json_encode($event->getMessageParameters()),
+				'priority' => IExtension::PRIORITY_MEDIUM,
+				'object_type' => $event->getObjectType(),
+				'object_id' => $event->getObjectId(),
+				'object_name' => $event->getObjectName(),
+				'link' => $event->getLink(),
+			]);
+
+			foreach ($affectedUsers as $affectedUser) {
+				$this->insertActivity->setParameter('affecteduser', $affectedUser);
+				$this->insertActivity->executeStatement();
+				$activityIds[$this->insertActivity->getLastInsertId()] = (string)$affectedUser;
+			}
+
+			$this->connection->commit();
+		} catch (Exception $e) {
+			// Make sure to always roll back, otherwise the outer code runs in a failed transaction
+			$this->logger->error('Could not create bulk activities', ['exception' => $e]);
+			$this->connection->rollBack();
+			return [];
+		}
+
+		return $activityIds;
+	}
+
 	/**
 	 * Send an event as email
 	 *
@@ -330,11 +403,21 @@ class Data {
 	 */
 	public function expire($expireDays = 365) {
 		$ttl = (60 * 60 * 24 * max(1, $expireDays));
-
 		$timelimit = time() - $ttl;
-		$this->deleteActivities([
+		$conditions = [
 			'timestamp' => [$timelimit, '<'],
-		]);
+		];
+
+		$excludedUsers = $this->config->getSystemValue('activity_expire_exclude_users', []);
+		if (!empty($excludedUsers)) {
+			foreach ($excludedUsers as $user) {
+				$conditions[] = [
+					'affecteduser' => [$user, '!=']
+				];
+			}
+		}
+
+		$this->deleteActivities($conditions);
 	}
 
 	/**
