@@ -73,19 +73,7 @@ OC.L10N.register(
     "Where: %s" : "地点：%s",
     "%1$s via %2$s" : "%1$s 通过 %2$s",
     "In the past on %1$s for the entire day" : "过去全天 %1$s ",
-    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["在 %n 分钟后全天 %1$s"],
-    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["在 %n 小时后全天 %1$s"],
-    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["在 %n 天后全天 %1$s"],
-    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["在 %n 周后全天 %1$s"],
-    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["在 %n 个月后全天 %1$s"],
-    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["在 %n 年后全天 %1$s"],
     "In the past on %1$s between %2$s - %3$s" : "过去  %2$s - %3$s %1$s",
-    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 分钟后 %1$s"],
-    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 小时后 %1$s"],
-    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 天后 %1$s"],
-    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 周后 %1$s"],
-    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 个月后 %1$s"],
-    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 年后 %1$s"],
     "Could not generate when statement" : "无法生成 when 语句",
     "Every Day for the entire day" : "每天全天",
     "Every Day for the entire day until %1$s" : "每天全天，直到 %1$s",
@@ -123,26 +111,8 @@ OC.L10N.register(
     "On specific dates for the entire day until %1$s" : "在特定日期全天，直到 %1$s",
     "On specific dates between %1$s - %2$s until %3$s" : "在 %1$s - %2$s 特定日期，直到 %3$s",
     "In the past on %1$s" : "在过去 %1$s",
-    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%n 分钟后 %1$s"],
-    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%n 小时后 %1$s"],
-    "_In a day on %1$s_::_In %n days on %1$s_" : ["%n 天后 %1$s"],
-    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%n 周后 %1$s"],
-    "_In a month on %1$s_::_In %n months on %1$s_" : ["%n 个月后 %1$s"],
-    "_In a year on %1$s_::_In %n years on %1$s_" : ["%n 年后 %1$s"],
     "In the past on %1$s then on %2$s" : "过去 %1$s，然后 %2$s",
-    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["%n 分钟后 %1$s，然后 %2$s"],
-    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["%n 小时后 %1$s，然后 %2$s"],
-    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["%n 天后 %1$s，然后 %2$s"],
-    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["%n 周后 %1$s，然后 %2$s"],
-    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["%n 个月后 %1$s，然后 %2$s"],
-    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["%n 年后 %1$s，然后 %2$s"],
     "In the past on %1$s then on %2$s and %3$s" : "在过去 %1$s，然后 %2$s 和 %3$s",
-    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%n 分钟后 %1$s，然后 %2$s 和 %3$s"],
-    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%n 小时后 %1$s，然后 %2$s 和 %3$s"],
-    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%n 天后 %1$s，然后 %2$s 和 %3$s"],
-    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%n 周后 %1$s，然后 %2$s 和 %3$s"],
-    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%n 个月后 %1$s，然后 %2$s 和 %3$s"],
-    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%n 年后 %1$s，然后 %2$s 和 %3$s"],
     "Could not generate next recurrence statement" : "无法生成下一个重复语句",
     "Cancelled: %1$s" : "已取消：%1$s",
     "\"%1$s\" has been canceled" : "“%1$s”已取消",
@@ -156,7 +126,7 @@ OC.L10N.register(
     "Invitation: %1$s" : "邀请：%1$s",
     "%1$s would like to invite you to \"%2$s\"" : "%1$s 想邀请您加入“%2$s”",
     "Organizer:" : "组织者：",
-    "Attendees:" : "与会者：",
+    "Attendees:" : "参加者：",
     "Title:" : "标题：",
     "When:" : "时间：",
     "Location:" : "地区：",
@@ -220,6 +190,8 @@ OC.L10N.register(
     "{actor} updated contact {card} in address book {addressbook}" : "{actor} 更新了通讯录 {addressbook} 中的联系人 {card} ",
     "You updated contact {card} in address book {addressbook}" : "你更新了通讯录 {addressbook} 中的联系人 {card} ",
     "A <strong>contact</strong> or <strong>address book</strong> was modified" : "一名 <strong>联系人</strong>或一个<strong>通讯录</strong>被更改了",
+    "System address book disabled" : "系统通讯录已禁用",
+    "The system contacts address book has been automatically disabled during upgrade. This means that the address book will no longer be available to users in the contacts app or other clients. The system contacts address book was disabled because the amount of contacts in the address book exceeded the maximum recommended number of contacts. This limit is set to prevent performance issues. You can re-enable the system address book with the following command {command}" : "系统联系人通讯录在升级期间已自动禁用。这意味着联系人应用或其他客户端中的用户将无法再使用通讯录。系统联系人通讯录已禁用，因为通讯录中的联系人数量超过了推荐的最大联系人数量。设置此限制是为了防止性能问题。您可以使用以下命令重新启用系统通讯录 {command}",
     "Accounts" : "账号",
     "System address book which holds all accounts" : "包含所有账号的系统通讯录",
     "File is not updatable: %1$s" : "无法更新文件：%1$s",
@@ -250,18 +222,24 @@ OC.L10N.register(
     "Completed on %s" : "已完成 %s",
     "Due on %s by %s" : "到期于 %s，在 %s 之前",
     "Due on %s" : "到期于 %s",
+    "Welcome to Nextcloud Calendar!\n\nThis is a sample event - explore the flexibility of planning with Nextcloud Calendar by making any edits you want!\n\nWith Nextcloud Calendar, you can:\n- Create, edit, and manage events effortlessly.\n- Create multiple calendars and share them with teammates, friends, or family.\n- Check availability and display your busy times to others.\n- Seamlessly integrate with apps and devices via CalDAV.\n- Customize your experience: schedule recurring events, adjust notifications and other settings." : "欢迎使用 Nextcloud 日历！\n\n这是一个示例事件——探索使用 Nextcloud 日历进行规划的灵活性，进行任何您想要的编辑！\n\n使用 Nextcloud 日历，您可以：\n- 轻松创建、编辑和管理事件。\n- 创建多个日历并与队友、朋友或家人共享。\n- 查看空闲时间并向他人显示您的忙碌时间。\n- 通过 CalDAV 与应用和设备无缝集成。\n- 自定义您的体验：安排重复事件、调整通知和其他设置。",
+    "Example event - open me!" : "示例事件——打开我！",
     "System Address Book" : "系统通讯录",
     "The system address book contains contact information for all users in your instance." : "系统通讯录包含实例中所有用户的联系人信息。",
     "Enable System Address Book" : "启用系统通讯录",
     "DAV system address book" : "DAV 系统通讯录",
     "No outstanding DAV system address book sync." : "书书未完成 DAV 系统通讯录的同步",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV 系统通讯录同步失败，这可能是因为你的服务器实例有超过1000名用户，或是因为出现了错误。请手动运行指令 “occ dav:sync-system-addressbook” 继续该操作。",
+    "DAV system address book size" : "DAV 系统通讯录大小",
+    "The system address book is disabled" : "系统通讯录已禁用",
+    "The system address book is enabled, but contains more than the configured limit of %d contacts" : "系统通讯录已启用，但包含的联系人超过了配置的 %d 个限制",
+    "The system address book is enabled and contains less than the configured limit of %d contacts" : "系统通讯录已启用，且包含的联系人少于配置的 %d 个限制",
     "WebDAV endpoint" : "WebDAV 端点",
     "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "无法检查您的 Web 服务器是否已正确设置以允许通过 WebDAV 进行文件同步。 请手动检查。",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "您的网页服务器没有正确设置允许文件同步，因为 WebDAV 接口看起来无法正常工作。",
     "Your web server is properly set up to allow file synchronization over WebDAV." : "您的 Web 服务器已正确设置为允许通过 WebDAV 进行文件同步。",
     "Migrated calendar (%1$s)" : "迁移的日历（%1$s）",
-    "Calendars including events, details and attendees" : "日历包含活动、参与人和事件详情",
+    "Calendars including events, details and attendees" : "日历，包括事件、详情和参加者",
     "Contacts and groups" : "联系人和群组",
     "WebDAV" : "WebDAV",
     "Absence saved" : "缺席已保存",
@@ -272,8 +250,6 @@ OC.L10N.register(
     "Last day (inclusive)" : "最后一天（含）",
     "Out of office replacement (optional)" : "外出时工作替代人员（可选）",
     "Name of the replacement" : "替代人员名称",
-    "No results." : "没有结果。",
-    "Start typing." : "开始输入",
     "Short absence status" : "短暂离开状态",
     "Long absence Message" : "长期离开信息",
     "Save" : "保存",
@@ -281,7 +257,6 @@ OC.L10N.register(
     "Failed to load availability" : "可用时间段加载失败",
     "Saved availability" : "可用时间已保存",
     "Failed to save availability" : "可用时间保存失败",
-    "Time zone:" : "时区：",
     "to" : "到",
     "Delete slot" : "删除插槽",
     "No working hours set" : "尚未设置工作时间",
@@ -289,23 +264,7 @@ OC.L10N.register(
     "Weekdays" : "工作日",
     "Pick a start time for {dayName}" : "选择 {dayName} 的开始时间",
     "Pick a end time for {dayName}" : "选择 {dayName} 的结束时间",
-    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "不在工作时间内时，自动将用户状态设置为“请勿打扰”并静音所有通知。",
-    "Availability" : "工作时间",
-    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "如果你配置了工作时间，其他人在预订会议时会看到你何时不在办公室。",
-    "Absence" : "离开",
-    "Configure your next absence period." : "配置你的下一次离开时段",
-    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装{calendarappstoreopen}日历应用{linkclose}，或者{calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
-    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置{emailopen}邮件服务器{linkclose}。",
-    "Calendar server" : "日历服务器",
-    "Send invitations to attendees" : "向与会者发送邀请",
-    "Automatically generate a birthday calendar" : "自动生成生日日历",
-    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
-    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
-    "Send notifications for events" : "发送事件通知",
-    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
-    "Send reminder notifications to calendar sharees as well" : "同时向日历共享者发送提醒通知",
-    "Reminders are always sent to organizers and attendees." : "始终向组织者和与会者发出提醒。",
-    "Enable notifications for events via push" : "启用推送事件通知",
+    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "不在工作时间内时，自动将用户状态设置为“勿扰”并静音所有通知。",
     "Cancel" : "取消",
     "Import" : "导入",
     "Error while saving settings" : "保存设置时出错",
@@ -313,20 +272,73 @@ OC.L10N.register(
     "Error while resetting contact" : "重置联系人时出错",
     "Contact imported successfully" : "联系人导入成功",
     "Error while importing contact" : "导入联系人时出错",
-    "Example Content" : "示例内容",
-    "Set example content to be created on new user first login." : "设置新用户首次登录时要创建的示例内容。",
     "Import contact" : "导入联系人",
-    "Reset to default contact" : "重置为默认联系人",
+    "Reset to default" : "重置为默认设置",
     "Import contacts" : "导入联系人",
     "Importing a new .vcf file will delete the existing default contact and replace it with the new one. Do you want to continue?" : "导入新的 .vcf 文件将删除现有的默认联系人，并用新联系人替换。是否要继续？",
+    "Failed to save example event creation setting" : "无法保存示例事件创建设置",
+    "Failed to upload the example event" : "无法上传示例事件",
+    "Custom example event was saved successfully" : "已成功保存自定义示例事件",
+    "Failed to delete the custom example event" : "无法删除自定义示例事件",
+    "Custom example event was deleted successfully" : "已成功删除自定义示例事件",
+    "Import calendar event" : "导入日历事件",
+    "Uploading a new event will overwrite the existing one." : "上传新事件将覆盖现有事件。",
+    "Upload event" : "上传事件",
+    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "也安装{calendarappstoreopen}日历应用{linkclose}，或者{calendardocopen}连接您的桌面和移动端同步日历 ↗{linkclose}。",
+    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "请确保正确设置{emailopen}邮件服务器{linkclose}。",
+    "Calendar server" : "日历服务器",
+    "Send invitations to attendees" : "向参加者发送邀请",
+    "Automatically generate a birthday calendar" : "自动生成生日日历",
+    "Birthday calendars will be generated by a background job." : "生日日历将由后台作业生成。",
+    "Hence they will not be available immediately after enabling but will show up after some time." : "因此，它们在启用后不会立即可用，但会在一段时间后显示出来。",
+    "Send notifications for events" : "发送事件通知",
+    "Notifications are sent via background jobs, so these must occur often enough." : "通知将通过后台任务发送，所以任务的频率要足够高。",
+    "Send reminder notifications to calendar sharees as well" : "同时向日历共享者发送提醒通知",
+    "Reminders are always sent to organizers and attendees." : "始终向组织者和参加者发送提醒。",
+    "Enable notifications for events via push" : "启用推送事件通知",
+    "Example content" : "示例内容",
+    "Example content serves to showcase the features of Nextcloud. Default content is shipped with Nextcloud, and can be replaced by custom content." : "示例内容用于展示 Nextcloud 的功能。默认内容随 Nextcloud 一起提供，可以用自定义内容替换。",
+    "Availability" : "工作时间",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "如果你配置了工作时间，其他人在预订会议时会看到你何时不在办公室。",
+    "Absence" : "离开",
+    "Configure your next absence period." : "配置你的下一次离开时段",
     "There was an error updating your attendance status." : "更新您的出席状态时出错。",
     "Please contact the organizer directly." : "请直接联系组织者。",
     "Are you accepting the invitation?" : "您是否接受邀请？",
     "Tentative" : "暂定",
     "Your attendance was updated successfully." : "您的出席状态更新成功。",
-    "Time:" : "时间：",
-    "Could not open file" : "无法打开文件",
-    "Invalid chunk name" : "分片名称无效",
-    "Could not rename part file assembled from chunks" : "无法重命名从分片组合的部分文件"
+    "_In a minute on %1$s for the entire day_::_In %n minutes on %1$s for the entire day_" : ["在 %n 分钟后全天 %1$s"],
+    "_In a hour on %1$s for the entire day_::_In %n hours on %1$s for the entire day_" : ["在 %n 小时后全天 %1$s"],
+    "_In a day on %1$s for the entire day_::_In %n days on %1$s for the entire day_" : ["在 %n 天后全天 %1$s"],
+    "_In a week on %1$s for the entire day_::_In %n weeks on %1$s for the entire day_" : ["在 %n 周后全天 %1$s"],
+    "_In a month on %1$s for the entire day_::_In %n months on %1$s for the entire day_" : ["在 %n 个月后全天 %1$s"],
+    "_In a year on %1$s for the entire day_::_In %n years on %1$s for the entire day_" : ["在 %n 年后全天 %1$s"],
+    "_In a minute on %1$s between %2$s - %3$s_::_In %n minutes on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 分钟后 %1$s"],
+    "_In a hour on %1$s between %2$s - %3$s_::_In %n hours on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 小时后 %1$s"],
+    "_In a day on %1$s between %2$s - %3$s_::_In %n days on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 天后 %1$s"],
+    "_In a week on %1$s between %2$s - %3$s_::_In %n weeks on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 周后 %1$s"],
+    "_In a month on %1$s between %2$s - %3$s_::_In %n months on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 个月后 %1$s"],
+    "_In a year on %1$s between %2$s - %3$s_::_In %n years on %1$s between %2$s - %3$s_" : ["在 %2$s - %3$s %n 年后 %1$s"],
+    "_In a minute on %1$s_::_In %n minutes on %1$s_" : ["%n 分钟后 %1$s"],
+    "_In a hour on %1$s_::_In %n hours on %1$s_" : ["%n 小时后 %1$s"],
+    "_In a day on %1$s_::_In %n days on %1$s_" : ["%n 天后 %1$s"],
+    "_In a week on %1$s_::_In %n weeks on %1$s_" : ["%n 周后 %1$s"],
+    "_In a month on %1$s_::_In %n months on %1$s_" : ["%n 个月后 %1$s"],
+    "_In a year on %1$s_::_In %n years on %1$s_" : ["%n 年后 %1$s"],
+    "_In a minute on %1$s then on %2$s_::_In %n minutes on %1$s then on %2$s_" : ["%n 分钟后 %1$s，然后 %2$s"],
+    "_In a hour on %1$s then on %2$s_::_In %n hours on %1$s then on %2$s_" : ["%n 小时后 %1$s，然后 %2$s"],
+    "_In a day on %1$s then on %2$s_::_In %n days on %1$s then on %2$s_" : ["%n 天后 %1$s，然后 %2$s"],
+    "_In a week on %1$s then on %2$s_::_In %n weeks on %1$s then on %2$s_" : ["%n 周后 %1$s，然后 %2$s"],
+    "_In a month on %1$s then on %2$s_::_In %n months on %1$s then on %2$s_" : ["%n 个月后 %1$s，然后 %2$s"],
+    "_In a year on %1$s then on %2$s_::_In %n years on %1$s then on %2$s_" : ["%n 年后 %1$s，然后 %2$s"],
+    "_In a minute on %1$s then on %2$s and %3$s_::_In %n minutes on %1$s then on %2$s and %3$s_" : ["%n 分钟后 %1$s，然后 %2$s 和 %3$s"],
+    "_In a hour on %1$s then on %2$s and %3$s_::_In %n hours on %1$s then on %2$s and %3$s_" : ["%n 小时后 %1$s，然后 %2$s 和 %3$s"],
+    "_In a day on %1$s then on %2$s and %3$s_::_In %n days on %1$s then on %2$s and %3$s_" : ["%n 天后 %1$s，然后 %2$s 和 %3$s"],
+    "_In a week on %1$s then on %2$s and %3$s_::_In %n weeks on %1$s then on %2$s and %3$s_" : ["%n 周后 %1$s，然后 %2$s 和 %3$s"],
+    "_In a month on %1$s then on %2$s and %3$s_::_In %n months on %1$s then on %2$s and %3$s_" : ["%n 个月后 %1$s，然后 %2$s 和 %3$s"],
+    "_In a year on %1$s then on %2$s and %3$s_::_In %n years on %1$s then on %2$s and %3$s_" : ["%n 年后 %1$s，然后 %2$s 和 %3$s"],
+    "No results." : "没有结果。",
+    "Start typing." : "开始输入",
+    "Time zone:" : "时区："
 },
 "nplurals=1; plural=0;");
