@@ -108,6 +108,39 @@ OC.L10N.register(
     "Type" : "Τύπος",
     "Active filters" : "Ενεργά φίλτρα",
     "Remove filter" : "Αφαίρεση φίλτρου",
+    "Appearance" : "Εμφάνιση",
+    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
+    "Show file type column" : "Εμφάνιση στήλης τύπου αρχείου",
+    "Show file extensions" : "Εμφάνιση επεκτάσεων αρχείων",
+    "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
+    "General" : "Γενικά",
+    "Sort favorites first" : "Ταξινόμηση των αγαπημένων πρώτα",
+    "Sort folders before files" : "Ταξινόμηση φακέλων πριν από τα αρχεία",
+    "Default view" : "Προεπιλεγμένη προβολή",
+    "All files" : "Όλα τα αρχεία",
+    "Personal files" : "Προσωπικά αρχεία",
+    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
+    "Actions" : "Ενέργειες",
+    "File actions" : "Ενέργειες αρχείου",
+    "Selection" : "Επιλογή",
+    "Select all files" : "Επιλογή όλων των αρχείων",
+    "Deselect all" : "Αναίρεση επιλογής όλων",
+    "Select or deselect" : "Επιλογή ή αναίρεση επιλογής",
+    "Select a range" : "Επιλογή εύρους",
+    "Navigation" : "Πλοήγηση",
+    "Go to parent folder" : "Μετάβαση στον γονικό φάκελο",
+    "Go to file above" : "Μετάβαση στο αρχείο πάνω",
+    "Go to file below" : "Μετάβαση στο αρχείο κάτω",
+    "Go left in grid" : "Μετάβαση αριστερά στο πλέγμα",
+    "Go right in grid" : "Μετάβαση δεξιά στο πλέγμα",
+    "View" : "Προβολή",
+    "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
+    "Open file sidebar" : "Άνοιγμα πλευρικής μπάρας αρχείου",
+    "Show those shortcuts" : "Εμφάνιση αυτών των συντομεύσεων",
+    "Warnings" : "Προειδοποιήσεις",
+    "Warn before changing a file extension" : "Προειδοποίηση πριν από την αλλαγή επέκτασης αρχείου",
+    "WebDAV URL" : "WebDAV URL",
+    "How to access files using WebDAV" : "Πώς να αποκτήσετε πρόσβαση σε αρχεία χρησιμοποιώντας WebDAV",
     "Total rows summary" : "Συνολική σύνοψη γραμμών",
     "Toggle selection for all files and folders" : "Εναλλαγή επιλογής για όλα τα αρχεία και τους φακέλους",
     "Name" : "Όνομα",
@@ -116,7 +149,6 @@ OC.L10N.register(
     "{displayName}: failed on some elements" : "{displayName}: απέτυχε σε ορισμένα στοιχεία",
     "{displayName}: done" : "{displayName}: ολοκληρώθηκε",
     "{displayName}: failed" : "{displayName}: απέτυχε",
-    "Actions" : "Ενέργειες",
     "(selected)" : "(επιλεγμένα)",
     "List of files and folders." : "Λίστα αρχείων και φακέλων.",
     "You have used your space quota and cannot upload files anymore." : "Έχετε χρησιμοποιήσει το όριο χώρου σας και δεν μπορείτε να μεταφορτώσετε αρχεία πλέον.",
@@ -124,8 +156,8 @@ OC.L10N.register(
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Η λίστα αυτή δεν εμφανίζεται πλήρως για λόγους απόδοσης. Τα αρχεία θα εμφανίζονται καθώς πλοηγείστε στη λίστα.",
     "File not found" : "Δε βρέθηκε το αρχείο",
     "_{count} selected_::_{count} selected_" : ["{count} επιλεγμένο","{count} επιλεγμένα"],
-    "Search everywhere …" : "Αναζήτηση παντού …",
-    "Search here …" : "Αναζήτηση εδώ …",
+    "Search everywhere …" : "Αναζήτηση παντού …",
+    "Search here …" : "Αναζήτηση εδώ …",
     "Search scope options" : "Επιλογές εμβέλειας αναζήτησης",
     "Search here" : "Αναζήτηση εδώ",
     "{usedQuotaByte} used" : "{usedQuotaByte} χρησιμοποιείται",
@@ -144,7 +176,7 @@ OC.L10N.register(
     "Failed to refresh filename sanitization status." : "Αποτυχία ανανέωσης κατάστασης καθαρισμού ονομάτων αρχείων.",
     "Filename sanitization in progress." : "Ο καθαρισμός ονομάτων αρχείων βρίσκεται σε εξέλιξη.",
     "Currently {processedUsers} of {totalUsers} accounts are already processed." : "Προς το παρόν {processedUsers} από {totalUsers} λογαριασμοί έχουν ήδη επεξεργαστεί.",
-    "Preparing …" : "Προετοιμασία …",
+    "Preparing …" : "Προετοιμασία …",
     "Refresh" : "Ανανέωση",
     "All files have been santized for Windows filename support." : "Όλα τα αρχεία έχουν καθαριστεί για υποστήριξη ονομάτων αρχείων Windows.",
     "Some files could not be sanitized, please check your logs." : "Ορισμένα αρχεία δεν μπορούσαν να καθαριστούν, παρακαλώ ελέγξτε τα αρχεία καταγραφής σας.",
@@ -159,7 +191,7 @@ OC.L10N.register(
     "Sanitize filenames" : "Καθαρισμός ονομάτων αρχείων",
     "(starting)" : "(εκκίνηση)",
     "Fill template fields" : "Συμπλήρωση πεδίων προτύπου",
-    "Submitting fields …" : "Υποβολή πεδίων …",
+    "Submitting fields …" : "Υποβολή πεδίων …",
     "Submit" : "Υποβολή",
     "Choose a file or folder to transfer" : "Επιλέξτε αρχείο ή φάκελο για μεταφορά",
     "Transfer" : "Μεταφορά",
@@ -183,6 +215,7 @@ OC.L10N.register(
     "Do not show this dialog again." : "Να μην εμφανιστεί ξανά αυτό το παράθυρο διαλόγου.",
     "Select file or folder to link to" : "Επιλέξτε αρχείο ή φάκελο για σύνδεση",
     "Choose {file}" : "Επιλέξτε {file}",
+    "Files settings" : "Ρυθμίσεις αρχείων",
     "Share" : "Διαμοιρασμός",
     "Shared by link" : "Διαμοιρασμένα μέσω συνδέσμου",
     "Shared" : "Κοινόχρηστα",
@@ -201,63 +234,6 @@ OC.L10N.register(
     "Upload some content or sync with your devices!" : "Μεταφόρτωση περιεχομένου ή συγχρονισμός με τις συσκευές σας!",
     "Go back" : "Επιστροφή",
     "Views" : "Προβολές",
-    "Files settings" : "Ρυθμίσεις αρχείων",
-    "Your files" : "Τα αρχεία σας",
-    "Open in files" : "Άνοιγμα στα αρχεία",
-    "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
-    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το μοιράσει.",
-    "No search results for “{query}”" : "Δεν υπάρχουν αποτελέσματα αναζήτησης για \"{query}\"",
-    "Search for files" : "Αναζήτηση αρχείων",
-    "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
-    "WebDAV URL copied" : "Αντιγράφηκε η WebDAV URL",
-    "General" : "Γενικά",
-    "Default view" : "Προεπιλεγμένη προβολή",
-    "All files" : "Όλα τα αρχεία",
-    "Personal files" : "Προσωπικά αρχεία",
-    "Sort favorites first" : "Ταξινόμηση των αγαπημένων πρώτα",
-    "Sort folders before files" : "Ταξινόμηση φακέλων πριν από τα αρχεία",
-    "Folder tree" : "Δέντρο φακέλων",
-    "Appearance" : "Εμφάνιση",
-    "Show hidden files" : "Εμφάνιση κρυφών αρχείων",
-    "Show file type column" : "Εμφάνιση στήλης τύπου αρχείου",
-    "Show file extensions" : "Εμφάνιση επεκτάσεων αρχείων",
-    "Crop image previews" : "Περικοπή προεπισκόπησης εικόνας",
-    "Additional settings" : "Επιπρόσθετες ρυθμίσεις",
-    "WebDAV" : "WebDAV",
-    "WebDAV URL" : "WebDAV URL",
-    "Copy" : "Αντιγραφή",
-    "How to access files using WebDAV" : "Πώς να αποκτήσετε πρόσβαση σε αρχεία χρησιμοποιώντας WebDAV",
-    "Two-Factor Authentication is enabled for your account, and therefore you need to use an app password to connect an external WebDAV client." : "Η Πιστοποίηση Δύο Παραγόντων είναι ενεργοποιημένη για το λογαριασμό σας, και επομένως πρέπει να χρησιμοποιήσετε έναν κωδικό εφαρμογής για να συνδεθείτε με έναν εξωτερικό πελάτη WebDAV.",
-    "Warnings" : "Προειδοποιήσεις",
-    "Warn before changing a file extension" : "Προειδοποίηση πριν από την αλλαγή επέκτασης αρχείου",
-    "Warn before deleting files" : "Προειδοποίηση πριν από τη διαγραφή αρχείων",
-    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
-    "File actions" : "Ενέργειες αρχείου",
-    "Rename" : "Μετονομασία",
-    "Delete" : "Διαγραφή",
-    "Add or remove favorite" : "Προσθήκη ή αφαίρεση αγαπημένου",
-    "Manage tags" : "Διαχείριση ετικετών",
-    "Selection" : "Επιλογή",
-    "Select all files" : "Επιλογή όλων των αρχείων",
-    "Deselect all" : "Αναίρεση επιλογής όλων",
-    "Select or deselect" : "Επιλογή ή αναίρεση επιλογής",
-    "Select a range" : "Επιλογή εύρους",
-    "Navigation" : "Πλοήγηση",
-    "Go to parent folder" : "Μετάβαση στον γονικό φάκελο",
-    "Go to file above" : "Μετάβαση στο αρχείο πάνω",
-    "Go to file below" : "Μετάβαση στο αρχείο κάτω",
-    "Go left in grid" : "Μετάβαση αριστερά στο πλέγμα",
-    "Go right in grid" : "Μετάβαση δεξιά στο πλέγμα",
-    "View" : "Προβολή",
-    "Toggle grid view" : "Εναλλαγή σε προβολή πλέγματος",
-    "Open file sidebar" : "Άνοιγμα πλευρικής μπάρας αρχείου",
-    "Show those shortcuts" : "Εμφάνιση αυτών των συντομεύσεων",
-    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Επιτρέπει τον περιορισμό ονομάτων αρχείων για να διασφαλιστεί ότι τα αρχεία μπορούν να συγχρονιστούν με όλους τους πελάτες. Από προεπιλογή επιτρέπονται όλα τα ονόματα αρχείων που είναι έγκυρα στο POSIX (π.χ. Linux ή macOS).",
-    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Μετά την ενεργοποίηση των συμβατών ονομάτων αρχείων Windows, τα υπάρχοντα αρχεία δεν μπορούν πλέον να τροποποιηθούν αλλά μπορούν να μετονομαστούν σε έγκυρα νέα ονόματα από τον κάτοχό τους.",
-    "Failed to toggle Windows filename support" : "Αποτυχία εναλλαγής υποστήριξης ονομάτων αρχείων Windows",
-    "Files compatibility" : "Συμβατότητα αρχείων",
-    "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
-    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμμόρφωση ως προς την διάκριση πεζών-κεφαλαίων.",
     "You" : "Εσύ",
     "Shared multiple times with different people" : "Κοινοποιήθηκε πολλές φορές με διαφορετικά άτομα",
     "Unable to change the favorite state of the file" : "Αδυναμία αλλαγής της κατάστασης αγαπημένου του αρχείου",
@@ -266,25 +242,35 @@ OC.L10N.register(
     "Remove from favorites" : "Αφαίρεση από τα αγαπημένα",
     "Add to favorites" : "Προσθήκη στα αγαπημένα",
     "Tags" : "Ετικέτες",
+    "Your files" : "Τα αρχεία σας",
+    "Open in files" : "Άνοιγμα στα αρχεία",
+    "File cannot be accessed" : "Δεν είναι δυνατή η πρόσβαση στο αρχείο",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Το αρχείο δεν βρέθηκε ή δεν έχετε δικαιώματα προβολής του. Ζητήστε από τον αποστολέα να το μοιράσει.",
+    "No search results for “{query}”" : "Δεν υπάρχουν αποτελέσματα αναζήτησης για \"{query}\"",
+    "Search for files" : "Αναζήτηση αρχείων",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Επιτρέπει τον περιορισμό ονομάτων αρχείων για να διασφαλιστεί ότι τα αρχεία μπορούν να συγχρονιστούν με όλους τους πελάτες. Από προεπιλογή επιτρέπονται όλα τα ονόματα αρχείων που είναι έγκυρα στο POSIX (π.χ. Linux ή macOS).",
+    "After enabling the Windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Μετά την ενεργοποίηση των συμβατών ονομάτων αρχείων Windows, τα υπάρχοντα αρχεία δεν μπορούν πλέον να τροποποιηθούν αλλά μπορούν να μετονομαστούν σε έγκυρα νέα ονόματα από τον κάτοχό τους.",
+    "Failed to toggle Windows filename support" : "Αποτυχία εναλλαγής υποστήριξης ονομάτων αρχείων Windows",
+    "Files compatibility" : "Συμβατότητα αρχείων",
+    "Enforce Windows compatibility" : "Επιβολή συμβατότητας με Windows",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Αυτό θα αποκλείσει ονόματα αρχείων που δεν είναι έγκυρα σε συστήματα Windows, όπως η χρήση δεσμευμένων ονομάτων ή ειδικών χαρακτήρων. Αλλά αυτό δεν θα επιβάλει τη συμμόρφωση ως προς την διάκριση πεζών-κεφαλαίων.",
     "Blank" : "Κενό",
     "Unable to create new file from template" : "Δεν είναι δυνατή η δημιουργία νέου αρχείου από το πρότυπο",
     "Pick a template for {name}" : "Επιλέξτε ένα πρότυπο για {name}",
     "Create a new file with the selected template" : "Δημιουργήστε ένα νέο αρχείο με το επιλεγμένο πρότυπο",
     "Creating file" : "Δημιουργία αρχείου",
     "Save as {displayName}" : "Αποθήκευση ως {displayName}",
-    "Save as …" : "Αποθήκευση ως …",
-    "Converting files …" : "Μετατροπή αρχείων …",
+    "Save as …" : "Αποθήκευση ως …",
+    "Converting files …" : "Μετατροπή αρχείων …",
     "Failed to convert files: {message}" : "Αποτυχία μετατροπής αρχείων: {message}",
     "All files failed to be converted" : "Όλα τα αρχεία απέτυχαν να μετατραπούν",
     "One file could not be converted: {message}" : "Ένα αρχείο δεν μπορούσε να μετατραπεί: {message}",
-    "_One file could not be converted_::_%n files could not be converted_" : ["Ένα αρχείο δεν μπορούσε να μετατραπεί","%n αρχεία δεν μπορούσαν να μετατραπούν"],
-    "_One file successfully converted_::_%n files successfully converted_" : ["Ένα αρχείο μετατράπηκε επιτυχώς","%n αρχεία μετατράπηκαν επιτυχώς"],
-    "Files successfully converted" : "Τα αρχεία μετατράπηκαν επιτυχώς",
     "Failed to convert files" : "Αποτυχία μετατροπής αρχείων",
-    "Converting file …" : "Μετατροπή αρχείου …",
+    "Converting file …" : "Μετατροπή αρχείων …",
     "File successfully converted" : "Το αρχείο μετατράπηκε επιτυχώς",
     "Failed to convert file: {message}" : "Αποτυχία μετατροπής αρχείου: {message}",
     "Failed to convert file" : "Αποτυχία μετατροπής αρχείου",
+    "Delete" : "Διαγραφή",
     "Leave this share" : "Αποχώρηση από αυτό το κοινόχρηστο",
     "Leave these shares" : "Αποχώρηση από αυτά τα κοινόχρηστα",
     "Disconnect storage" : "Αποσύνδεση αποθηκευτικού χώρου",
@@ -302,8 +288,7 @@ OC.L10N.register(
     "Download" : "Λήψη",
     "The requested file is not available." : "Το ζητούμενο αρχείο δεν είναι διαθέσιμο.",
     "The requested files are not available." : "Τα ζητούμενα αρχεία δεν είναι διαθέσιμα.",
-    "Moving \"{source}\" to \"{destination}\" …" : "Μετακίνηση του \"{source}\" στο \"{destination}\" …",
-    "Copying \"{source}\" to \"{destination}\" …" : "Αντιγραφή του \"{source}\" στο \"{destination}\" …",
+    "Add or remove favorite" : "Προσθήκη ή αφαίρεση αγαπημένου",
     "Destination is not a folder" : "Ο προορισμός δεν είναι φάκελος",
     "This file/folder is already in that directory" : "Αυτό το αρχείο/φάκελος βρίσκεται ήδη σε αυτόν τον κατάλογο",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Δεν μπορείτε να μετακινήσετε ένα αρχείο/φάκελο στον εαυτό του ή σε έναν υποφάκελο του ίδιου του φακέλου.",
@@ -314,6 +299,7 @@ OC.L10N.register(
     "The file does not exist anymore" : "Το αρχείο δεν υπάρχει πλέον",
     "Choose destination" : "Επιλέξτε προορισμό",
     "Copy to {target}" : "Αντιγραφή σε {target}",
+    "Copy" : "Αντιγραφή",
     "Move to {target}" : "Μετακίνηση σε {target}",
     "Move" : "Μετακίνηση",
     "Move or copy operation failed" : "Η λειτουργία μετακίνησης ή αντιγραφής απέτυχε",
@@ -326,6 +312,7 @@ OC.L10N.register(
     "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Το αρχείο θα πρέπει τώρα να ανοίξει στη συσκευή σας. Εάν δεν ανοίξει, παρακαλώ ελέγξτε ότι έχετε εγκατεστημένη την εφαρμογή στον υπολογιστή.",
     "Retry and close" : "Δοκιμή ξανά και κλείσιμο",
     "Open online" : "Άνοιγμα online",
+    "Rename" : "Μετονομασία",
     "Details" : "Λεπτομέρειες",
     "View in folder" : "Προβολή στον φάκελο",
     "Today" : "Σήμερα",
@@ -381,6 +368,7 @@ OC.L10N.register(
     "No favorites yet" : "Κανένα αγαπημένο ακόμα",
     "Files and folders you mark as favorite will show up here" : "Τα αρχεία και οι φάκελοι που σημειώνονται ως αγαπημένα θα εμφανιστούν εδώ",
     "List of your files and folders." : "Λίστα των αρχείων και φακέλων σας.",
+    "Folder tree" : "Δέντρο φακέλων",
     "List of your files and folders that are not shared." : "Λίστα αρχείων και φακέλων που δεν είναι κοινόχρηστα.",
     "No personal files found" : "Δε βρέθηκαν προσωπικά αρχεία",
     "Files that are not shared will show up here." : "Τα αρχεία που δεν είναι κοινόχρηστα θα εμφανίζονται εδώ.",
@@ -394,119 +382,28 @@ OC.L10N.register(
     "Select all" : "Επιλογή όλων",
     "Upload too large" : "Πολύ μεγάλο αρχείο προς μεταφόρτωση",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Τα αρχεία που προσπαθείτε να μεταφορτώσετε υπερβαίνουν το μέγιστο μέγεθος μεταφόρτωσης αρχείων σε αυτόν τον διακομιστή.",
-    "File could not be found" : "Δεν μπορεί να βρεθεί το αρχείο",
-    "Show list view" : "Προβολή λίστας",
-    "Show grid view" : "Προβολή πλέγματος",
-    "Close" : "Κλείσιμο",
-    "Could not create folder \"{dir}\"" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\"",
-    "This will stop your current uploads." : "Αυτό θα σταματήσει τις τρέχουσες μεταφορτώσεις.",
-    "Upload cancelled." : "Η μεταφόρτωση ακυρώθηκε.",
-    "Processing files …" : "Γίνεται επεξεργασία των αρχείων …",
-    "…" : "…",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Αδυναμία φόρτωσης {filename} καθώς είναι κατάλογος ή έχει 0 bytes",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Δεν υπάρχει αρκετός ελεύθερος χώρος, μεταφορτώνεται {size1} αλλά υπάρχει χώρος μόνο για {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "Ο φάκελος προορισμού \"{dir}\" δεν υπάρχει πλέον",
-    "An unknown error has occurred" : "Προέκυψε άγνωστο σφάλμα.",
-    "File could not be uploaded" : "Δεν ήταν δυνατή η μεταφόρτωση του αρχείου",
-    "Uploading …" : "Μεταφόρτωση σε εξέλιξη ...",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "Μεταφόρτωση … ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} από {totalSize} ({bitrate})",
-    "Uploading that item is not supported" : "Η μεταφόρτωση αυτού του αντικειμένου δεν υποστηρίζεται",
-    "Error when assembling chunks, status code {status}" : "Σφάλμα κατά την συλλογή τμημάτων, κωδικός κατάστασης {status}",
-    "Choose target folder" : "Επιλογή φακέλου προορισμού",
-    "Set reminder" : "Προσθήκη υπενθύμισης",
-    "Edit locally" : "Επεξεργασία τοπικά",
-    "Open" : "Άνοιγμα",
-    "Could not load info for file \"{file}\"" : "Αδυναμία φόρτωσης πληροφοριών για το αρχείο \"{file}\"",
-    "Please select tag(s) to add to the selection" : "Επιλέξτε ετικέτα (ες) για προσθήκη στην επιλογή",
-    "Apply tag(s) to selection" : "Εφαρμογή ετικετών στην επιλογή",
-    "Select directory \"{dirName}\"" : "Επιλέξτε κατάλογο \"{dirName}\"",
-    "Select file \"{fileName}\"" : "Επιλέξτε αρχείο \"{fileName}\"",
-    "Unable to determine date" : "Αδυναμία προσδιορισμού ημερομηνίας",
-    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
-    "Could not move \"{file}\", target exists" : "Αδυναμία μετακίνησης του \"{file}\", υπάρχει ήδη αρχείο με αυτό το όνομα",
-    "Could not move \"{file}\"" : "Αδυναμία μετακίνησης του \"{file}\"",
-    "copy" : "αντιγραφή",
-    "Could not copy \"{file}\", target exists" : "Αδυναμία αντιγραφής του \"{file}\", υπάρχει ήδη.",
-    "Could not copy \"{file}\"" : "Αδυναμία αντιγραφής του \"{file}\"",
-    "Copied {origin} inside {destination}" : "Αντιγράφτηκε το {origin} στο {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "Αντιγράφτηκε το {origin} και {nbfiles} άλλα αρχεία στο {destination}",
-    "{newName} already exists" : "Το {newName} υπάρχει ήδη",
-    "Could not create file \"{file}\"" : "Αδυναμία δημιουργίας του αρχείου \"{file}\"",
-    "Could not create file \"{file}\" because it already exists" : "Αδυναμία δημιουργίας του αρχείου \"{file}\" επειδή υπάρχει ήδη",
-    "Could not create folder \"{dir}\" because it already exists" : "Αδυναμία δημιουργίας του φακέλου \"{dir}\" επειδή υπάρχει ήδη",
-    "Could not fetch file details \"{file}\"" : "Δεν είναι δυνατή η ανάγνωση λεπτομερειών του αρχείου \"{file}\"",
-    "Error deleting file \"{fileName}\"." : "Σφάλμα διαγραφής του \"{fileName}\".",
-    "No search results in other folders for {tag}{filter}{endtag}" : "Κανένα αποτέλεσμα αναζήτησης σε άλλους φακέλους για {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "Εισαγάγετε περισσότερους από δύο χαρακτήρες για αναζήτηση σε άλλους φακέλους",
-    "{dirs} and {files}" : "{dirs} και {files}",
-    "_including %n hidden_::_including %n hidden_" : ["περιλαμβάνεται %n κρυφό","περιλαμβάνονται %n κρυφά"],
-    "You do not have permission to upload or create files here" : "Δεν έχετε δικαιώματα μεταφόρτωσης ή δημιουργίας αρχείων εδώ",
-    "_Uploading %n file_::_Uploading %n files_" : ["Μεταφόρτωση %n αρχείου","Μεταφόρτωση %n αρχείων"],
-    "New" : "Νέα",
-    "New file/folder menu" : "Μενού νέου αρχείου/φακέλου",
-    "Select file range" : "Επιλέξτε εύρος αρχείων",
-    "{used}%" : "{used}%",
-    "{used} used" : "Σε χρήση {used}",
-    "\"{name}\" is an invalid file name." : "Το \"{name}\" δεν είναι έγκυρο όνομα αρχείου.",
-    "File name cannot be empty." : "Το όνομα αρχείου δεν μπορεί να είναι κενό.",
-    "\"/\" is not allowed inside a file name." : "Το \"/\" δεν είναι επιτρεπτό εντός του ονόματος αρχείου.",
-    "\"{name}\" is not an allowed filetype" : "Το \"{name}\" δεν είναι ένας επιτρεπτός τύπος αρχείου",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Ο αποθηκευτικός χώρος του/της {owner} είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ο φάκελος της ομάδας \"{mountPoint}\" είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
-    "Your storage is full, files cannot be updated or synced anymore!" : "Ο αποθηκευτικός σας χώρος είναι πλήρης, τα αρχεία δεν μπορούν να ενημερωθούν ή να συγχρονιστούν πλέον!",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός χώρος του {owner} είναι σχεδόν γεμάτος ({usedSpacePercent}%)",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο φάκελος ομάδας \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Ο εξωτερικός χώρος αποθήκευσης \"{mountPoint}\" είναι σχεδόν πλήρης ({usedSpacePercent}%).",
-    "Your storage is almost full ({usedSpacePercent}%)." : "Ο αποθηκευτικός σας χώρος είναι σχεδόν γεμάτος ({usedSpacePercent}%).",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["Ταιριάζει \"{filter}\"","Ταιριάζουν \"{filter}\""],
-    "Direct link was copied (only works for people who have access to this file/folder)" : "Ο άμεσος σύνδεσμος αντιγράφηκε (λειτουργεί μόνο για άτομα που έχουν πρόσβαση σε αυτό το αρχείο/φάκελο)",
-    "Path" : "Διαδρομή",
-    "_%n byte_::_%n bytes_" : ["%n byte","%n bytes"],
-    "Favored" : "Αγαπημένο",
-    "Favor" : "Αγαπημένο",
-    "Copy direct link (only works for people who have access to this file/folder)" : "Αντιγραφή άμεσου συνδέσμου (λειτουργεί μόνο για άτομα που έχουν πρόσβαση στο αρχείο/φάκελο)",
-    "Upload file" : "Μεταφόρτωση αρχείου",
-    "Not favored" : "Μη αγαπημένο",
-    "An error occurred while trying to update the tags" : "Ένα σφάλμα προέκυψε κατά τη διάρκεια ενημέρωσης των ετικετών",
+    "%1$s (renamed)" : "%1$s (μετονομάστηκε)",
+    "renamed file" : "μετονομασμένο αρχείο",
     "Upload (max. %s)" : "Μεταφόρτωση (max. %s)",
-    "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
-    "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
+    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Μετά την ενεργοποίηση των συμβατών ονομάτων αρχείων Windows, τα υπάρχοντα αρχεία δεν μπορούν πλέον να τροποποιηθούν αλλά μπορούν να μετονομαστούν σε έγκυρα νέα ονόματα από τον κάτοχό τους.",
+    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Είναι επίσης δυνατή η αυτόματη μετεγκατάσταση αρχείων μετά την ενεργοποίηση αυτής της ρύθμισης, παρακαλώ ανατρέξτε στην τεκμηρίωση σχετικά με την εντολή occ.",
     "\"{displayName}\" failed on some elements" : "Ο/Η \"{displayName}\" απέτυχε σε ορισμένα στοιχεία",
     "\"{displayName}\" batch action executed successfully" : "Η μαζική ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
-    "Submitting fields…" : "Υποβολή πεδίων…",
-    "Filter filenames…" : "Φιλτράρετε τα ονόματα αρχείων...",
+    "\"{displayName}\" action failed" : "Η ενέργεια του \"{displayName}\" απέτυχε",
+    "Submitting fields …" : "Υποβολή πεδίων …",
+    "\"{displayName}\" action executed successfully" : "Η ενέργεια του/της \"{displayName}\" εκτελέστηκε επιτυχώς",
+    "Filter file names …" : "Φιλτράρισμα ονομάτων αρχείων …",
+    "Clipboard is not available" : "Το πρόχειρο δεν είναι διαθέσιμο",
     "WebDAV URL copied to clipboard" : "Ο σύνδεσμος WebDAV αντιγράφηκε στο πρόχειρο",
     "Enable the grid view" : "Ενεργοποίηση της προβολής πλέγματος",
     "Enable folder tree" : "Ενεργοποίηση δέντρου φακέλων",
+    "WebDAV" : "WebDAV",
     "Copy to clipboard" : "Αντιγραφή στο πρόχειρο",
     "Use this address to access your Files via WebDAV" : "Χρήση αυτής της διεύθυνσης για πρόσβαση στα Αρχεία σας μέσω WebDAV",
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Εάν έχετε ενεργοποιήσει το 2FA, πρέπει να δημιουργήσετε και να χρησιμοποιήσετε έναν νέο κωδικό πρόσβασης εφαρμογής κάνοντας κλικ εδώ.",
-    "Deletion cancelled" : "Διαγραφή ακυρώθηκε",
-    "Move cancelled" : "Μετακίνηση ακυρώθηκε",
-    "Cancelled move or copy of \"{filename}\"." : "Ακυρώθηκε η μετακίνηση ή αντιγραφή του \"{filename}\".",
-    "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
-    "Open details" : "Άνοιγμα λεπτομερειών",
-    "Photos and images" : "Φωτογραφίες και εικόνες",
-    "New folder creation cancelled" : "Ακυρώθηκε η δημιουργία νέου φακέλου",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} φάκελος","{folderCount} φακέλοι"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} αρχείο","{fileCount} αρχεία"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 αρχείο και {folderCount} φάκελος","1 αρχείο και {folderCount} φακέλοι"],
-    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} αρχείο και 1 φάκελος","{fileCount} αρχεία και 1 φάκελος"],
-    "{fileCount} files and {folderCount} folders" : "{fileCount} αρχεία και {folderCount} φακέλοι",
-    "All folders" : "Όλοι οι φάκελοι",
-    "Personal Files" : "Προσωπικά Αρχεία",
-    "Text file" : "Αρχείο κειμένου",
-    "New text file.txt" : "Νέο αρχείο file.txt",
-    "%1$s (renamed)" : "%1$s (μετονομάστηκε)",
-    "renamed file" : "μετονομασμένο αρχείο",
-    "After enabling the windows compatible filenames, existing files cannot be modified anymore but can be renamed to valid new names by their owner." : "Μετά την ενεργοποίηση των συμβατών ονομάτων αρχείων Windows, τα υπάρχοντα αρχεία δεν μπορούν πλέον να τροποποιηθούν αλλά μπορούν να μετονομαστούν σε έγκυρα νέα ονόματα από τον κάτοχό τους.",
-    "It is also possible to migrate files automatically after enabling this setting, please refer to the documentation about the occ command." : "Είναι επίσης δυνατή η αυτόματη μετεγκατάσταση αρχείων μετά την ενεργοποίηση αυτής της ρύθμισης, παρακαλώ ανατρέξτε στην τεκμηρίωση σχετικά με την εντολή occ.",
-    "Filter file names …" : "Φιλτράρισμα ονομάτων αρχείων …",
     "Prevent warning dialogs from open or reenable them." : "Αποτροπή ανοίγματος παραθύρων προειδοποίησης ή επανενεργοποίησή τους.",
     "Show a warning dialog when changing a file extension." : "Εμφάνιση παραθύρου προειδοποίησης κατά την αλλαγή επέκτασης αρχείου.",
+    "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
     "Speed up your Files experience with these quick shortcuts." : "Επιταχύνετε την εμπειρία σας στα Αρχεία με αυτές τις γρήγορες συντόμευσεις.",
     "Open the actions menu for a file" : "Άνοιγμα του μενού ενεργειών για ένα αρχείο",
     "Rename a file" : "Μετονομασία αρχείου",
@@ -522,6 +419,24 @@ OC.L10N.register(
     "Navigate to the file on the left (in grid mode)" : "Πλοήγηση στο αρχείο αριστερά (σε λειτουργία πλέγματος)",
     "Navigate to the file on the right (in grid mode)" : "Πλοήγηση στο αρχείο δεξιά (σε λειτουργία πλέγματος)",
     "Toggle the grid view" : "Εναλλαγή προβολής πλέγματος",
-    "Open the sidebar for a file" : "Άνοιγμα πλευρικής μπάρας για ένα αρχείο"
+    "Open the sidebar for a file" : "Άνοιγμα πλευρικής μπάρας για ένα αρχείο",
+    "Save as …" : "Αποθήκευση ως …",
+    "Converting files …" : "Μετατροπή αρχείων …",
+    "Converting file …" : "Μετατροπή αρχείου …",
+    "Deletion cancelled" : "Διαγραφή ακυρώθηκε",
+    "Edit locally" : "Επεξεργασία τοπικά",
+    "Moving \"{source}\" to \"{destination}\" …" : "Μετακίνηση του \"{source}\" στο \"{destination}\" …",
+    "Copying \"{source}\" to \"{destination}\" …" : "Αντιγραφή του \"{source}\" στο \"{destination}\" …",
+    "Move cancelled" : "Μετακίνηση ακυρώθηκε",
+    "Cancelled move or copy of \"{filename}\"." : "Ακυρώθηκε η μετακίνηση ή αντιγραφή του \"{filename}\".",
+    "Cancelled move or copy operation" : "Ακυρώθηκε η λειτουργία μετακίνησης ή αντιγραφής",
+    "Open details" : "Άνοιγμα λεπτομερειών",
+    "Photos and images" : "Φωτογραφίες και εικόνες",
+    "New folder creation cancelled" : "Ακυρώθηκε η δημιουργία νέου φακέλου",
+    "This directory is unavailable, please check the logs or contact the administrator" : "Ο κατάλογος δεν είναι διαθέσιμος, παρακαλούμε ελέγξτε τα αρχεία καταγραφής ή επικοινωνήστε με το διαχειριστή",
+    "All folders" : "Όλοι οι φάκελοι",
+    "Search everywhere …" : "Αναζήτηση παντού …",
+    "Search here …" : "Αναζήτηση εδώ …",
+    "Preparing …" : "Προετοιμασία …"
 },
 "nplurals=2; plural=(n != 1);");
