@@ -55,6 +55,7 @@ OC.L10N.register(
     "Share for file {file} with {user} expired" : "Tiedoston {file} jako käyttäjän {user} kanssa on päättynyt",
     "Share for file {file} expired" : "Tiedoston {file} jako vanhentui",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Tiedosto tai kansio, joka on jaettu sähköpostitse tai julkisen linkin kautta, on <strong>ladattu</strong>",
+    "Files have been <strong>uploaded</strong> to a folder shared by mail or by public link" : "Tiedostoja on <strong>lähetetty</strong> kansioon, joka on jaettu sähköpostitse tai julkisella linkillä",
     "A file or folder was shared from <strong>another server</strong>" : "Tiedosto tai kansio on jaettu <strong>toiselta palvelimelta</strong>",
     "Sharing" : "Jakaminen",
     "A file or folder has been <strong>shared</strong>" : "Tiedosto tai kansio on <strong>jaettu</strong>",
@@ -67,8 +68,10 @@ OC.L10N.register(
     "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
     "Please specify a valid group" : "Määritä kelvollinen ryhmä",
     "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
+    "Please specify a valid email address" : "Määritä kelvollinen sähköpostiosoite",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
+    "Please specify a valid team" : "Määritä kelvollinen tiimi",
     "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
     "Unknown share type" : "Tuntematon jaon tyyppi",
     "Not a directory" : "Ei hakemisto",
@@ -79,6 +82,7 @@ OC.L10N.register(
     "Could not lock path" : "Polun lukitseminen ei onnistunut",
     "Wrong or no update parameter given" : "Päivitettävä parametri puuttuu tai on väärin",
     "Wrong password" : "Väärä salasana",
+    "This share does not exist or is no longer available" : "Jakoa ei ole olemassa tai se ei ole enää saatavilla",
     "shared by %s" : "käyttäjän %s jakama",
     "Download" : "Lataa",
     "Add to your %s" : "Lisää %siisi",
@@ -91,19 +95,52 @@ OC.L10N.register(
     "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
+    "Remember to upload the files to %s" : "Muista lähettää tiedostot kansioon %s",
+    "We would like to kindly remind you that you have not yet uploaded any files to the shared folder." : "Muistutamme, ettet ole lähettänyt yhtäkään tiedostoa jaettuun kansioon.",
+    "Open \"%s\"" : "Avaa \"%s\"",
     "People" : "Ihmiset",
+    "Filter accounts" : "Suodata tilejä",
+    "The request will be password protected." : "Pyyntö suojataan salasanalla.",
+    "When should the request expire?" : "Milloin pyynnön tulee vanhentua?",
     "Expiration date" : "Vanhenemispäivä",
+    "Select a date" : "Valitse päivämäärä",
     "Set a password" : "Aseta salasana",
     "Password" : "Salasana",
-    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
+    "Enter a valid password" : "Kirjoita oikea salasana",
+    "Generate a new password" : "Luo uusi salasana",
+    "Your administrator has enforced a password protection." : "Ylläpitäjä on pakottanut salasanasuojauksen.",
+    "Link copied" : "Linkki kopioitu",
+    "Email already added" : "Sähköpostiosoite on jo lisätty",
+    "Invalid email address" : "Virheellinen sähköpostiosoite",
+    "_{count} email address added_::_{count} email addresses added_" : ["{count} sähköpostiosoite lisätty","{count} sähköpostiosoitetta lisätty"],
     "Share link" : "Jaa linkki",
-    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Copy" : "Kopioi",
     "Send link via email" : "Lähetä linkki sähköpostitse",
+    "Enter an email address or paste a list" : "Kirjoita sähköpostiosoite tai liitä lista",
+    "Remove email" : "Poista sähköpostiosoite",
+    "Select a destination" : "Valitse sijainti",
     "Select" : "Valitse",
+    "What are you requesting?" : "Mitä pyydät?",
+    "Request subject" : "Pyynnön aihe",
+    "Birthday party photos, History assignment…" : "Syntymäpäiväkuvia, historiantehtäviä…",
+    "Where should these files go?" : "Mihin nämä tiedostot kuuluvat?",
+    "Upload destination" : "Lähetyksen kohde",
+    "The uploaded files are visible only to you unless you choose to share them." : "Lähetetyt tiedostot ovat vain sinulle näkyvissä, ellet päätä jakaa niitä.",
+    "Add a note" : "Lisää muistiinpano",
     "Close" : "Sulje",
+    "_Send email and close_::_Send {count} emails and close_" : ["Lähetä sähköposti ja sulje","Lähetä {count} sähköpostia ja sulje"],
+    "File request created" : "Tiedostopyyntö luotu",
+    "_File request created and email sent_::_File request created and {count} emails sent_" : ["Tiedostopyyntö luotu ja sähköposti lähetetty","Tiedostopyyntö luotu ja {count} sähköpostia lähetetty"],
     "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
     "Error creating the share" : "Virhe jakoa luotaessa",
+    "Error sending emails: {errorMessage}" : "Virhe sähköposteja lähettäessä: {errorMessage}",
+    "Error sending emails" : "Virhe sähköposteja lähettäessä",
+    "Create a file request" : "Luo tiedostopyyntö",
+    "File request" : "Tiedostopyyntö",
+    "Previous step" : "Edellinen vaihe",
     "Cancel" : "Peruuta",
+    "Cancel the file request creation" : "Peru tiedostopyynnön luominen",
+    "Close without sending emails" : "Sulje lähettämättä sähköposteja",
     "Continue" : "Jatka",
     "Accept shares from other accounts and groups by default" : "Hyväksy jaot muilta tileiltä ja ryhmiltä oletusarvoisesti",
     "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
@@ -112,6 +149,8 @@ OC.L10N.register(
     "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
     "Reset" : "Palauta",
     "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
+    "Share expiration: {date}" : "Jaon vanheneminen: {date}",
+    "Share Expiration" : "Jaon vanheneminen",
     "group" : "ryhmä",
     "conversation" : "keskustelu",
     "remote" : "etä",
@@ -125,16 +164,16 @@ OC.L10N.register(
     "Via “{folder}”" : "“{folder}” kautta",
     "Unshare" : "Lopeta jakaminen",
     "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
-    "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
-    "Link copied" : "Linkki kopioitu",
+    "Copy internal link" : "Kopioi sisäinen linkki",
     "Internal link" : "Sisäinen linkki",
     "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
+    "File request ({label})" : "Tiedostopyyntö ({label})",
     "Mail share ({label})" : "Sähköpostijako ({label})",
     "Share link ({label})" : "Jaa linkki ({label})",
     "Share link ({index})" : "Jaa linkki ({index})",
     "Create public link" : "Luo julkinen linkki",
     "Actions for \"{title}\"" : "Toiminnot kohteelle \"{title}\"",
-    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
+    "Copy public link of \"{title}\"" : "Kopioi kohteen \"{title}\" julkinen linkki",
     "Error, please enter proper password and/or expiration date" : "Virhe, lisää kelvollinen salasana ja/tai päättymispäivä",
     "Link share created" : "Linkkijako luotu",
     "Error while creating the share" : "Virhe jakoa luotaessa",
@@ -151,11 +190,8 @@ OC.L10N.register(
     "Can edit" : "Voi muokata",
     "Custom permissions" : "Mukautetut oikeudet",
     "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
-    "Name or email …" : "Nimi tai sähköposti...",
-    "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
-    "Searching …" : "Haetaan…",
     "No elements found." : "Elementtejä ei löytynyt.",
-    "Search globally" : "Hae globaalisti",
+    "Search everywhere" : "Etsi kaikkialta",
     "Guest" : "Vieras",
     "Group" : "Ryhmä",
     "Email" : "Sähköposti",
@@ -165,9 +201,10 @@ OC.L10N.register(
     "on {server}" : "palvelimella {server}",
     "Note:" : "Huomioi:",
     "File drop" : "Tiedoston pudotus",
+    "Upload files to {foldername}." : "Lähetä tiedostot kansioon {foldername}.",
+    "By uploading files, you agree to the terms of service." : "Lähettämällä tiedostot hyväksyt käyttöehdot.",
+    "View terms of service" : "Näytä käyttöehdot",
     "Terms of service" : "Käyttöehdot",
-    "Nickname" : "Nimimerkki",
-    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
     "Share with group" : "Jaa ryhmän kanssa",
     "Share in conversation" : "Jaa keskustelussa",
     "Share with remote group" : "Jaa etäryhmän kanssa",
@@ -179,10 +216,13 @@ OC.L10N.register(
     "Edit" : "Muokkaa",
     "Share" : "Jaa",
     "Delete" : "Poista",
+    "Password field cannot be empty" : "Salasanakenttä ei voi olla tyhjä",
+    "Replace current password" : "Korvaa nykyinen salasana",
     "Allow upload and editing" : "Salli lähetys ja muokkaus",
     "Allow editing" : "Salli muokkaus",
     "Advanced settings" : "Lisäasetukset",
     "Share label" : "Jaon nimi",
+    "Generating…" : "Luodaan…",
     "Set password" : "Aseta salasana",
     "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
     "Password expired" : "Salasana vanheni",
@@ -192,11 +232,14 @@ OC.L10N.register(
     "Hide download" : "Piilota lataus",
     "Note to recipient" : "Huomio vastaanottajalle",
     "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
+    "Show files in grid view" : "Näytä tiedostot ruudukkonäkymässä",
     "Delete share" : "Poista jako",
     "Others with access" : "Muut, joilla on käyttöoikeus",
     "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
     "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
     "Shares" : "Jaot",
+    "Type names or teams" : "Kirjoita nimet tai tiimit",
+    "Type an email" : "Kirjoita sähköpostiosoite",
     "Unable to load the shares list" : "Jakolistan haku epäonnistui",
     "Expires {relativetime}" : "Vanhenee {relativetime}",
     "this share just expired." : "tämä jako vanheni juuri.",
@@ -211,10 +254,16 @@ OC.L10N.register(
     "Shared" : "Jaettu",
     "Shared by {ownerDisplayName}" : "Jakanut {ownerDisplayName}",
     "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
-    "Show sharing options" : "Näytä jakamisen valinnat",
+    "Sharing options" : "Jakamisen valinnat",
     "Shared with others" : "Jaettu muiden kanssa",
+    "Create file request" : "Luo tiedostopyyntö",
+    "Upload files to {foldername}" : "Lähetä tiedostot kansioon {foldername}",
+    "Public file share" : "Julkinen tiedostojako",
+    "Publicly shared file." : "Tiedosto jaettu julkisesti.",
     "No file" : "Ei tiedostoa",
     "Public share" : "Julkinen jako",
+    "Publicly shared files." : "Julkisesti jaetut tiedostot.",
+    "No files" : "Ei tiedostoja",
     "Overview of shared files." : "Yleisnäkymä jaetuista tiedostoista.",
     "No shares" : "Ei jakoja",
     "Files and folders you shared or have been shared with you will show up here" : "Tiedostot ja kansiot, jotka olet jakanut tai jotka on jaettu kanssasi, näkyvät täällä",
@@ -229,6 +278,9 @@ OC.L10N.register(
     "List of files that are shared by link." : "Luettelo tiedostoista, jotka on jaettu linkin kautta.",
     "No shared links" : "Ei jaettuja linkkejä",
     "Files and folders you shared by link will show up here" : "Linkin kautta jakamasi tiedostot ja kansiot näkyvät täällä",
+    "File requests" : "Tiedostopyynnöt",
+    "List of file requests." : "Lista tiedostopyynnöistä.",
+    "No file requests" : "Ei tiedostopyyntöjä",
     "Deleted shares" : "Poistetut jaot",
     "No deleted shares" : "Ei poistettuja jakoja",
     "Pending shares" : "Odottavat jaot",
@@ -239,39 +291,45 @@ OC.L10N.register(
     "Error updating the share" : "Virhe jakoa päivittäessä",
     "File \"{path}\" has been unshared" : "Tiedoston \"{path}\" jakaminen on lopetettu",
     "Folder \"{path}\" has been unshared" : "Kansion \"{path}\" jakaminen on lopetettu",
-    "Shared by" : "Jakanut",
-    "Shared with" : "Jaettu",
+    "Share saved" : "Jako tallennettu",
+    "Share password saved" : "Jaon salasana tallennettu",
+    "Share permissions saved" : "Jaon oikeudet tallennettu",
+    "Upload files to {folder}" : "Lähetä tiedostot kansioon {folder}",
+    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} jakoi kansion kanssasi.",
+    "Names must not be empty." : "Nimet eivät voi olla tyhjiä.",
+    "Invalid name." : "Virheellinen nimi.",
     "Password created successfully" : "Salasana luotu onnistuneesti",
     "Shared with you and the group {group} by {owner}" : "Jaettu sinun ja ryhmän {group} kanssa käyttäjältä {owner}",
     "Shared with you and {circle} by {owner}" : "{owner} on jakanut tämän sinun ja piirin {circle} kanssa",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} on jakanut tämän sinun ja keskustelun {conversation} kanssa",
     "Shared with you in a conversation by {owner}" : "{owner} jakoi tämän kanssasi keskustelussa",
+    "Share not found" : "Jakoa ei löytynyt",
+    "Back to %s" : "Takaisin kohtaan %s",
+    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
+    "Link copied to clipboard" : "Linkki kopioitu leikepöydälle",
+    "Copy to clipboard" : "Kopioi leikepöydälle",
+    "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
+    "Copy public link of \"{title}\" to clipboard" : "Kopioi kohteen \"{title}\" julkinen linkki leikepöydälle",
+    "Name or email …" : "Nimi tai sähköposti...",
+    "Name, email, or Federated Cloud ID …" : "Nimi, sähköposti tai federoitu Cloud ID...",
+    "Searching …" : "Haetaan…",
+    "Search globally" : "Hae globaalisti",
+    "Name" : "Nimi",
+    "Enter your name" : "Kirjoita nimesi",
+    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
+    "Show sharing options" : "Näytä jakamisen valinnat",
+    "Filename must not be empty." : "Tiedostonimi ei voi olla tyhjä.",
+    "Shared by" : "Jakanut",
+    "Shared with" : "Jaettu",
     "Share note" : "Jaa muistiinpano",
     "Show list view" : "Näytä listanäkymä",
     "Show grid view" : "Näytä ruudukkonäkymä",
     "Upload files to %s" : "Lähetä tiedostoja käyttäjälle %s",
+    "%s shared a folder with you." : "%s jakoi kansion kanssasi.",
     "Note" : "Huomio",
     "Select or drop files" : "Valitse tai pudota tiedostoja",
     "Uploading files" : "Lähetetään tiedostoja",
     "Uploaded files:" : "Lähetetyt tiedostot:",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s.",
-    "Share not found" : "Jakoa ei löytynyt",
-    "Back to %s" : "Takaisin kohtaan %s",
-    "Add to your Nextcloud" : "Lisää Nextcloudiisi",
-    "Waiting…" : "Odotetaan…",
-    "error" : "virhe",
-    "finished" : "valmis",
-    "This will stop your current uploads." : "Tämä pysäyttää meneillään olevat lähetykset.",
-    "Move or copy" : "Siirrä tai kopioi",
-    "You can upload into this folder" : "Voit lähettää tiedostoja tähän kansioon",
-    "No compatible server found at {remote}" : "Yhteensopivaa palvelinta ei löytynyt osoitteesta {remote}",
-    "Invalid server URL" : "Virheellinen palvelimen URL",
-    "Failed to add the public link to your Nextcloud" : "Julkisen linkin lisääminen Nextcloudiisi epäonnistui",
-    "Files" : "Tiedostot",
-    "Download all files" : "Lataa kaikki tiedostot",
-    "Search for share recipients" : "Etsi jaon vastaanottajia",
-    "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
-    "Allow download" : "Salli lataus",
-    "Enter your name" : "Kirjoita nimesi"
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "Tiedostoja lähettämällä hyväksyt %1$skäyttöehdot%2$s."
 },
 "nplurals=2; plural=(n != 1);");
