@@ -134,7 +134,7 @@ OC.L10N.register(
     "Generate a new password" : "產生新密碼",
     "Your administrator has enforced a password protection." : "您的管理員已強制設定密碼保護。",
     "Automatically copying failed, please copy the share link manually" : "自動複製失敗，請手動複製分享連結",
-    "Link copied to clipboard" : "已複製連結至剪貼簿",
+    "Link copied" : "連結已複製",
     "Email already added" : "已新增電子郵件",
     "Invalid email address" : "無效的電子郵件地址",
     "_The following email address is not valid: {emails}_::_The following email addresses are not valid: {emails}_" : ["以下電子郵件地址無效：{emails}"],
@@ -142,7 +142,7 @@ OC.L10N.register(
     "_{count} email address added_::_{count} email addresses added_" : ["新增了 {count} 個電子郵件地址"],
     "You can now share the link below to allow people to upload files to your directory." : "您現在可以分享下面的連結，讓其他人將檔案上傳到您的目錄中。",
     "Share link" : "分享連結",
-    "Copy to clipboard" : "複製到剪貼簿",
+    "Copy" : "複製",
     "Send link via email" : "透過 email 寄送連結",
     "Enter an email address or paste a list" : "請輸入電子郵件地址或貼上清單",
     "Remove email" : "移除電子郵件",
@@ -185,6 +185,8 @@ OC.L10N.register(
     "Set default folder for accepted shares" : "為接受的分享設定預設資料夾",
     "Reset" : "重設",
     "Reset folder to system default" : "將資料夾重設回系統預設",
+    "Share expiration: {date}" : "分享到期日：{date}",
+    "Share Expiration" : "分享過期",
     "group" : "群組",
     "conversation" : "對話",
     "remote" : "遠端",
@@ -199,10 +201,8 @@ OC.L10N.register(
     "Via “{folder}”" : "透過「{folder}」",
     "Unshare" : "取消分享",
     "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
-    "Copy internal link to clipboard" : "複製內部連結至剪貼簿",
-    "Only works for people with access to this folder" : "只對可以存取此資料夾的使用者生效",
-    "Only works for people with access to this file" : "只對可以存取此檔案的使用者生效",
-    "Link copied" : "連結已複製",
+    "Copy internal link" : "複製內部連結",
+    "For people who already have access" : "對於已有存取權限的人",
     "Internal link" : "內部連結",
     "{shareWith} by {initiator}" : "{initiator} {shareWith}",
     "Shared via link by {initiator}" : "{initiator} 透過連結分享",
@@ -213,10 +213,12 @@ OC.L10N.register(
     "Share link ({index})" : "分享連結 ({index})",
     "Create public link" : "建立公開連結",
     "Actions for \"{title}\"" : "「{title}」的動作",
-    "Copy public link of \"{title}\" to clipboard" : "將「{title}」的公開連結複製到剪貼簿",
+    "Copy public link of \"{title}\"" : "複製「{title}」的公開連結",
     "Error, please enter proper password and/or expiration date" : "錯誤，請輸入適當的密碼及/或到期日",
     "Link share created" : "建立了連結分享",
     "Error while creating the share" : "建立分享時發生錯誤",
+    "Your browser does not support copying, please copy the link manually:" : "您的瀏覽器不支援複製功能，請手動複製連結：",
+    "Successfully copied public link" : "複製公開連結成功",
     "Please enter the following required information before creating the share" : "在建立分享前，請輸入以下的必要資訊",
     "Password protection (enforced)" : "密碼保護（強制）",
     "Password protection" : "密碼保護",
@@ -235,11 +237,11 @@ OC.L10N.register(
     "Can edit" : "可以編輯",
     "Custom permissions" : "自訂權限",
     "Resharing is not allowed" : "不允許轉發分享",
-    "Name or email …" : "名稱或電子郵件…",
-    "Name, email, or Federated Cloud ID …" : "名稱、電子郵件或雲端聯邦 ID…",
-    "Searching …" : "正在搜尋…",
+    "Name or email …" : "名稱或電子郵件 ……",
+    "Name, email, or Federated Cloud ID …" : "名稱、電子郵件或雲端聯邦 ID ……",
+    "Searching …" : "正在搜尋 …",
     "No elements found." : "找不到元素。",
-    "Search globally" : "全域搜尋",
+    "Search everywhere" : "到處搜尋",
     "Guest" : "訪客",
     "Group" : "群組",
     "Email" : "電子郵件",
@@ -255,15 +257,10 @@ OC.L10N.register(
     "File drop" : "檔案投遞",
     "Upload files to {foldername}." : "上傳檔案至 {foldername}。",
     "By uploading files, you agree to the terms of service." : "上傳檔案即表示您同意服務條款。",
+    "Successfully uploaded files" : "已成功上傳檔案",
     "View terms of service" : "檢視服務條款",
     "Terms of service" : "服務條款",
-    "Upload files to {folder}" : "上傳檔案到 {folder}",
-    "Submit name" : "遞交名稱",
-    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 與您分享了一個資料夾。",
-    "To upload files, you need to provide your name first." : "要上傳檔案，您必須先提供您的名字。",
-    "Nickname" : "暱稱",
-    "Enter your nickname" : "輸入您的暱稱",
-    "Share with {userName}" : "與 {userName} 分享",
+    "Share with {user}" : "與 {user} 分享",
     "Share with email {email}" : "與電子郵件 {email} 分享",
     "Share with group" : "與群組分享",
     "Share in conversation" : "在對話中分享",
@@ -308,19 +305,22 @@ OC.L10N.register(
     "Unable to fetch inherited shares" : "無法擷取繼承的分享",
     "Link shares" : "連結分享",
     "Shares" : "分享",
-    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法與組織內的個人或團隊分享檔案。如果收件者已經可以存取分享但找不到，您可以將內部分享連結傳送給他們，以方便存取。",
-    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法與組織外的個人或組織分享檔案。檔案與資料夾可以透過公開的分享連結與電子郵件地址來分享。您也可以使用其他 Nextcloud 帳號的聯邦雲端 ID，將檔案分享給託管在不同站台上的其他 Nextcloud 帳號。",
-    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不屬於內部或外部分享的分享。這可能是來自應用程式或其他來源的分享。",
+    "Share files within your organization. Recipients who can already view the file can also use this link for easy access." : "在您的組織內部分享檔案。已經可以檢視檔案的收件者也可以使用此連結以方便存取。",
+    "Share files with others outside your organization via public links and email addresses. You can also share to {productName} accounts on other instances using their federated cloud ID." : "透過公開連結與電子郵件地址與組織外的其他人分享檔案。您也可以使用其他站台上的聯邦雲端 ID 將檔案分享至 {productName} 帳號。",
+    "Shares from apps or other sources which are not included in internal or external shares." : "來自應用程式或其他來源的分享，不包括在內部或外部分享中。",
+    "Type names, teams, federated cloud IDs" : "輸入名稱、團隊、聯邦雲端 ID",
+    "Type names or teams" : "輸入名稱或團隊",
+    "Type a federated cloud ID" : "輸入聯邦雲端 ID",
+    "Type an email" : "輸入電子郵件",
+    "Type an email or federated cloud ID" : "輸入電子郵件或聯邦雲端 ID",
     "Unable to load the shares list" : "無法載入分享列表",
     "Expires {relativetime}" : "過期於 {relativetime}",
     "this share just expired." : "此分享剛過期。",
     "Shared with you by {owner}" : "{owner} 已與您分享",
     "Internal shares" : "內部分享",
     "Internal shares explanation" : "內部分享說明",
-    "Share with accounts and teams" : "與帳號及團隊分享",
     "External shares" : "外部分享",
     "External shares explanation" : "外部分享說明",
-    "Email, federated cloud id" : "電子郵件、聯邦雲端 ID",
     "Additional shares" : "額外分享",
     "Additional shares explanation" : "額外分享說明",
     "Link to a file" : "檔案連結",
@@ -331,8 +331,9 @@ OC.L10N.register(
     "Shared" : "已分享",
     "Shared by {ownerDisplayName}" : "{ownerDisplayName} 分享",
     "Shared multiple times with different people" : "與不同的人多次分享",
-    "Show sharing options" : "顯示分享選項",
+    "Sharing options" : "分享選項",
     "Shared with others" : "與其他人分享",
+    "You do not have enough permissions to share this file." : "您無權分享此檔案。",
     "Create file request" : "建立檔案請求",
     "Upload files to {foldername}" : "上傳檔案至 {foldername}",
     "Public file share" : "公開連結分享",
@@ -369,6 +370,8 @@ OC.L10N.register(
     "List of unapproved shares." : "未批准的分享清單。",
     "No pending shares" : "沒有待處理的分享",
     "Shares you have received but not approved will show up here" : "您收到但尚未核准的分享將會在此顯示",
+    "Error deleting the share: {errorMessage}" : "刪除分享時發生錯誤：{errorMessage}",
+    "Error deleting the share" : "刪除分享時發生錯誤",
     "Error updating the share: {errorMessage}" : "更新分享時發生錯誤：{errorMessage}",
     "Error updating the share" : "更新分享時發生錯誤",
     "File \"{path}\" has been unshared" : "檔案「{path}」已取消分享",
@@ -381,14 +384,52 @@ OC.L10N.register(
     "Share note for recipient saved" : "已儲存給收件者的分享備註",
     "Share password saved" : "分享密碼已儲存",
     "Share permissions saved" : "已儲存分享權限",
-    "Shared by" : "分享者",
-    "Shared with" : "分享給",
+    "To upload files to {folder}, you need to provide your name first." : "要上傳檔案至 {folder}，您必須先提供您的名稱。",
+    "Upload files to {folder}" : "上傳檔案到 {folder}",
+    "Please confirm your name to upload files to {folder}" : "請確認您的名稱以上傳檔案至 {folder}",
+    "{ownerDisplayName} shared a folder with you." : "{ownerDisplayName} 與您分享了一個資料夾。",
+    "Names must not be empty." : "名稱不能為空。",
+    "Names must not start with a dot." : "名稱不能以點開頭。",
+    "\"{char}\" is not allowed inside a name." : "「{char}」不能在名稱內使用。",
+    "\"{segment}\" is a reserved name and not allowed." : "「{segment}」為保留名稱且不允許使用。",
+    "\"{extension}\" is not an allowed name." : "「{extension}」不是允許的名稱。",
+    "Names must not end with \"{extension}\"." : "名稱不能以「{extension}」結尾。",
+    "Invalid name." : "無效的名稱。",
     "Password created successfully" : "成功建立密碼",
     "Error generating password from password policy" : "從密碼策略產生密碼時發生錯誤",
     "Shared with you and the group {group} by {owner}" : "{owner} 與您和群組 {group} 分享",
     "Shared with you and {circle} by {owner}" : "{owner} 與您和 {circle} 分享",
     "Shared with you and the conversation {conversation} by {owner}" : "{owner} 與您和 {conversation} 對話分享",
     "Shared with you in a conversation by {owner}" : "{owner} 在對話中與您分享",
+    "Share not found" : "找不到分享",
+    "Back to %s" : "回到 %s",
+    "Add to your Nextcloud" : "新增到您的 Nextcloud",
+    "Link copied to clipboard" : "已複製連結至剪貼簿",
+    "Copy to clipboard" : "複製到剪貼簿",
+    "Copy internal link to clipboard" : "複製內部連結至剪貼簿",
+    "Only works for people with access to this folder" : "只對可以存取此資料夾的使用者生效",
+    "Only works for people with access to this file" : "只對可以存取此檔案的使用者生效",
+    "Copy public link of \"{title}\" to clipboard" : "將「{title}」的公開連結複製到剪貼簿",
+    "Name or email …" : "名稱或電子郵件…",
+    "Name, email, or Federated Cloud ID …" : "名稱、電子郵件或雲端聯邦 ID…",
+    "Searching …" : "正在搜尋…",
+    "Search globally" : "全域搜尋",
+    "Submit name" : "遞交名稱",
+    "To upload files, you need to provide your name first." : "要上傳檔案，您必須先提供您的名字。",
+    "Name" : "名稱",
+    "Enter your name" : "輸入您的名稱",
+    "Share with {userName}" : "與 {userName} 分享",
+    "Use this method to share files with individuals or teams within your organization. If the recipient already has access to the share but cannot locate it, you can send them the internal share link for easy access." : "使用此方法與組織內的個人或團隊分享檔案。如果收件者已經可以存取分享但找不到，您可以將內部分享連結傳送給他們，以方便存取。",
+    "Use this method to share files with individuals or organizations outside your organization. Files and folders can be shared via public share links and email addresses. You can also share to other Nextcloud accounts hosted on different instances using their federated cloud ID." : "使用此方法與組織外的個人或組織分享檔案。檔案與資料夾可以透過公開的分享連結與電子郵件地址來分享。您也可以使用其他 Nextcloud 帳號的聯邦雲端 ID，將檔案分享給託管在不同站台上的其他 Nextcloud 帳號。",
+    "Shares that are not part of the internal or external shares. This can be shares from apps or other sources." : "不屬於內部或外部分享的分享。這可能是來自應用程式或其他來源的分享。",
+    "Share with accounts, teams, federated cloud id" : "與帳號、團隊、聯邦雲端ID 分享",
+    "Share with accounts and teams" : "與帳號及團隊分享",
+    "Federated cloud ID" : "聯邦雲端 ID",
+    "Email, federated cloud id" : "電子郵件、聯邦雲端 ID",
+    "Show sharing options" : "顯示分享選項",
+    "Filename must not be empty." : "檔案名稱不能為空。",
+    "Shared by" : "分享者",
+    "Shared with" : "分享給",
     "Share note" : "分享備註",
     "Show list view" : "顯示清單檢視",
     "Show grid view" : "顯示格狀檢視",
@@ -398,29 +439,6 @@ OC.L10N.register(
     "Select or drop files" : "選取或拖曳檔案",
     "Uploading files" : "正在上傳檔案",
     "Uploaded files:" : "已上傳的檔案：",
-    "By uploading files, you agree to the %1$sterms of service%2$s." : "上傳檔案即表示您同意 %1$s服務條款%2$s。",
-    "Share not found" : "找不到分享",
-    "Back to %s" : "回到 %s",
-    "Add to your Nextcloud" : "新增到您的 Nextcloud",
-    "Waiting…" : "正在等待…",
-    "error" : "錯誤",
-    "finished" : "已完成",
-    "This will stop your current uploads." : "這會停止您目前的上傳。",
-    "Move or copy" : "移動或複製",
-    "You can upload into this folder" : "您可以上傳到此資料夾",
-    "No compatible server found at {remote}" : "在 {remote} 找不到相容的伺服器",
-    "Invalid server URL" : "無效的伺服器 URL",
-    "Failed to add the public link to your Nextcloud" : "無法將公開連結新增到您的 Nextcloud",
-    "Files" : "檔案",
-    "Download all files" : "下載所有檔案",
-    "Search for share recipients" : "搜尋分享接收者",
-    "No recommendations. Start typing." : "沒有建議。請開始輸入。",
-    "Password field can't be empty" : "密碼欄位不能為空",
-    "Allow download" : "允許下載",
-    "Share expire date saved" : "已儲存分享過期日期",
-    "You are not allowed to edit link shares that you don't own" : "您無權編輯不屬於您的連結分享",
-    "_1 email address already added_::_{count} email addresses already added_" : ["已新增 {count} 個電子郵件地址"],
-    "_1 email address added_::_{count} email addresses added_" : ["已新增 {count} 個電子郵件地址"],
-    "Enter your name" : "輸入您的名稱"
+    "By uploading files, you agree to the %1$sterms of service%2$s." : "上傳檔案即表示您同意 %1$s服務條款%2$s。"
 },
 "nplurals=1; plural=0;");
