@@ -85,6 +85,25 @@ OC.L10N.register(
     "Could not copy the URL, please copy manually" : "Tókst ekki að afrita slóðina, afritaðu hana handvirkt",
     "Server address" : "Vistfang þjóns",
     "Use this link to connect your apps and desktop client to this server:" : "Notaðu þessa slóð fyrir forritin þín til að tengjast þessum þjóni:",
+    "Global redesign and usability lift" : "Almenn endurhönnun og endurbætur á notagildi",
+    "New Office UI: colors, tabs, bars" : "Nýtt viðmót skrifstofuforrita: litir, flipar, stikur",
+    "Performance and stability boost" : "Bætt afköst og stöðugleiki",
+    "New AI Agency tools unlocked" : "Nýjum AI Agency verkfærum gefinn laus taumurinn",
+    "Talk threads & live transcription" : "Spjallþræðir og umritun í beinni",
+    "Calendar: date poll for participants" : "Dagatal: kosning um dagsetningar hjá þátttakendum",
+    "Intuitive file search" : "Aðgengileg leit að skrám",
+    "Teams 2.0 & quick Guest accounts" : "Teams 2.0 og fljótlegir gestaaðgangar",
+    "Quick presets & many other admin updates" : "Fljótlegar forstillingar og margar aðrar uppfærslur fyrir kerfisstjóra",
+    "Vue3, WebSockets and more OpenAPI for devs" : "Vue3, WebSockets og meira OpenAPI fyrir forritara",
+    "… and much more!" : "… og margt fleira!",
+    "Get to know the new features of Hub {version}" : "Kynntu þér nýja eiginleika í Hub {version}",
+    "Nextcloud Hub 25 Autumn – Your digital workspace, ready in no time ⚡" : "Nextcloud Hub 25 Autumn er komið – Stafrænta vinnusvæðið þitt, tilbúið í hvelli  ⚡",
+    "What's new?" : "Hvað er nýtt á döfinni?",
+    "Nextcloud on all your devices" : "Nextcloud á öllum tækjunum þínum",
+    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
+    "Read more" : "Lesa meira",
+    "Share on social media" : "Deila á samfélagsmiðlum",
+    "Get started!" : "Komast í gang!",
     "End-to-end encryption in calls and web" : "Enda-í-enda dulritun í símtölum og á vefnum",
     "Performance improvements across all our products" : "Afkastabæting í öllum hugbúnaðnum okkar",
     "Thousands of tweaks for improved UX and stability" : "Þúsundir lagfæringa á notendaviðmóti og stöðugleika",
@@ -93,24 +112,6 @@ OC.L10N.register(
     "Smarter team sharing with Team folders" : "Snjallari deiling teyma með teymamöppum",
     "Schedule meetings directly in Talk" : "Hægt að setj fundi á dagskrá beint í Talk-sjallforritinu",
     "Mail you love again: translations, summaries, and mentions" : "Tölvupóstur sem hentar þér: þýðingar, samantektir og hægt að minnast á e-n",
-    "Get to know the new features of Hub {version}" : "Kynntu þér nýja eiginleika í Hub {version}",
-    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 er komið – allsherjar stafrænt vinnusvæði byggt úr einingum! 💫",
-    "What's new?" : "Hvað er nýtt á döfinni?",
-    "Nextcloud on all your devices" : "Nextcloud á öllum tækjunum þínum",
-    "Nextcloud Hub {version}" : "Nextcloud Hub {version}",
-    "Read more" : "Lesa meira",
-    "Share on social media" : "Deila á samfélagsmiðlum",
-    "Get started!" : "Komast í gang!",
-    "App recommendation: Nextcloud Calendar" : "Forrit sem mælt er með: Nextcloud Calendar dagatalsforrit",
-    "App recommendation: Nextcloud Contacts" : "Forrit sem mælt er með: Nextcloud Contacts tengiliðaforrit",
-    "App recommendation: Nextcloud Mail" : "Forrit sem mælt er með: Nextcloud Mail póstforrit",
-    "Federated collaboration: file sharing, messaging, calls" : "Samvinna á skýjasambandi: deiling skráa, skilaboð, símtöl",
-    "Nextcloud Whiteboard" : "Nextcloud Whiteboard samvinnukerfið",
-    "Workflow Engine" : "Verkferlakerfi",
-    "Safer and swifter mail" : "Öruggari og sneggri tölvupóstur",
-    "Public Collectives sharing, previews and QR-codes" : "Deiling opinberra safna, forskoðun og QR-kóðar",
-    "Office and PDF templates" : "Sniðmát fyrir skrifstofuskjöl og PDF-skrár",
-    "Chat mode for Nextcloud Assistant" : "Spjallhamur fyrir Nextcloud Assistant",
-    "Get to know the new features of Hub 9" : "Kynntu þér nýja eiginleika í Hub 9"
+    "Nextcloud Hub 10 is here – your modular & unified digital workspace! 💫" : "Nextcloud Hub 10 er komið – allsherjar stafrænt vinnusvæði byggt úr einingum! 💫"
 },
 "nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
