@@ -9,39 +9,35 @@ declare(strict_types=1);
 namespace OCA\Photos\Service;
 
 use OCA\Photos\DB\Place\PlaceMapper;
-use OCP\FilesMetadata\Exceptions\FilesMetadataNotFoundException;
+use OCA\Photos\Listener\ExifMetadataProvider;
 use OCP\FilesMetadata\IFilesMetadataManager;
+use OCP\FilesMetadata\Model\IFilesMetadata;
 
 class MediaPlaceManager {
 	public function __construct(
-		private IFilesMetadataManager $filesMetadataManager,
-		private ReverseGeoCoderService $rgcService,
-		private PlaceMapper $placeMapper,
+		private readonly IFilesMetadataManager $filesMetadataManager,
+		private readonly ReverseGeoCoderService $rgcService,
+		private readonly PlaceMapper $placeMapper,
 	) {
 	}
 
 	public function setPlaceForFile(int $fileId): void {
-		$place = $this->getPlaceForFile($fileId);
+		$metadata = $this->filesMetadataManager->getMetadata($fileId, true);
+		$place = $this->getPlaceForMetadata($metadata);
 
 		if ($place === null) {
 			return;
 		}
 
-		$this->placeMapper->setPlaceForFile($place, $fileId);
+		$metadata->setString('gps', $place, true);
 	}
 
-	public function getPlaceForFile(int $fileId): ?string {
-		try {
-			$metadata = $this->filesMetadataManager->getMetadata($fileId, true);
-		} catch (FilesMetadataNotFoundException) {
+	public function getPlaceForMetadata(IFilesMetadata $metadata): ?string {
+		if (!$this->rgcService->arePlacesEnabled() || !$metadata->hasKey(ExifMetadataProvider::METADATA_KEY_GPS)) {
 			return null;
 		}
 
-		if (!$this->rgcService->arePlacesEnabled() || !$metadata->hasKey('photos-gps')) {
-			return null;
-		}
-
-		$coordinate = $metadata->getArray('photos-gps');
+		$coordinate = $metadata->getArray(ExifMetadataProvider::METADATA_KEY_GPS);
 
 		$latitude = $coordinate['latitude'] ?? null;
 		$longitude = $coordinate['longitude'] ?? null;
