@@ -5,10 +5,10 @@ OC.L10N.register(
     "No file was uploaded" : "N'eus restr ebet a zo bet kaset",
     "File not found" : "Restr ebet kavet",
     "Text" : "Testenn",
-    "Translate" : "Treiñ",
     "Reload" : "Adkargañ",
     "Guest" : "Kouviad",
     "edit" : "embann",
+    "Copy link" : "Eilañ al liamm",
     "guest" : "kouviad",
     "Offline" : "Distaget",
     "Saving …" : "Orc'h enrolliñ",
@@ -18,6 +18,7 @@ OC.L10N.register(
     "Save changes" : "Enrollañ ar cheñchamantoù",
     "Cancel" : "Nullañ",
     "URL" : "URL",
+    "Translate" : "Treiñ",
     "Translate to" : "Treiñ e",
     "Replace" : "Erlec'hiañ",
     "Upload" : "Enporzhiañ",
@@ -27,12 +28,7 @@ OC.L10N.register(
     "Command" : "Urzh",
     "Choose" : "Dibab",
     "Add folder description" : "Ouzhpennañ un deskrivadur evit ar renkell",
-    "Use current version" : "Implij stumm hiziv",
-    "Use the saved version" : "Implij ",
     "Edit guest name" : "Embannañ anv an hini pedet",
-    "Save guest name" : "Enrollañ anv an hini pedet",
-    "Info" : "Titouroù",
-    "Success" : "Graet",
-    "Warning" : "Kemenadenn"
+    "Save guest name" : "Enrollañ anv an hini pedet"
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
