@@ -12,10 +12,9 @@ OC.L10N.register(
     "New text file" : "Nuevo archivo de texto",
     "File not found" : "Archivo no encontrado",
     "Text" : "Texto",
-    "Translate" : "Traducir",
-    "Delete task" : "Eliminar tarea",
     "Guest" : "Invitado",
     "you" : "tú",
+    "Copy link" : "Copiar enlace",
     "Offline" : "Sin conexión",
     "Saved" : "Guardado",
     "Unsaved changes" : "Cambios no guardados",
@@ -26,7 +25,10 @@ OC.L10N.register(
     "Undo" : "Deshacer",
     "Save changes" : "Guardar cambios",
     "Cancel" : "Cancel",
+    "Save" : "Guardar",
     "Formatting help" : "Ayuda de formato",
+    "Translate" : "Traducir",
+    "Delete task" : "Eliminar tarea",
     "Select language" : "Selecciona el idioma",
     "to" : "para",
     "Replace" : "Reemplazar",
@@ -35,9 +37,6 @@ OC.L10N.register(
     "Source code" : "Código fuente",
     "Details" : "Detalles",
     "Choose" : "Seleccionar",
-    "Add folder description" : "Agregar una descripción a la carpeta",
-    "Info" : "Info",
-    "Success" : "Éxito",
-    "Warning" : "Advertencia"
+    "Add folder description" : "Agregar una descripción a la carpeta"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
