@@ -8,8 +8,9 @@ OC.L10N.register(
     "New text file" : "Nuevo archivo de texto",
     "File not found" : "Archivo no encontrado",
     "Text" : "Texto",
-    "Translate" : "Traducir",
     "Guest" : "Invitado",
+    "you" : "tú",
+    "Copy link" : "Copiar liga",
     "Offline" : "Sin conexión",
     "Saved" : "Guardado",
     "Unsaved changes" : "Cambios no guardados",
@@ -17,8 +18,11 @@ OC.L10N.register(
     "Link" : "Liga",
     "Action" : "Acción",
     "Undo" : "Deshacer",
+    "Cancel" : "Cancel",
     "URL" : "URL",
+    "Save" : "Guardar",
     "Formatting help" : "Ayuda de formato",
+    "Translate" : "Traducir",
     "Select language" : "Seleccionar idioma",
     "to" : "para",
     "Replace" : "Reemplazar",
@@ -26,8 +30,6 @@ OC.L10N.register(
     "Edit" : "Editar",
     "Source code" : "Código fuente",
     "Details" : "Detalles",
-    "Info" : "Info",
-    "Success" : "Éxito",
-    "Warning" : "Advertencia"
+    "Choose" : "Seleccionar"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
