@@ -2,20 +2,22 @@ OC.L10N.register(
     "text",
     {
     "File not found" : "Файл олдсонгүй",
-    "Translate" : "Орчуулга",
     "Guest" : "Зочин",
+    "you" : "та",
+    "edit" : "Засварлах",
     "Saved" : "Хадгалах",
     "Link" : "Холбоос",
     "Undo" : "буцах",
     "Cancel" : "Цуцлах",
     "URL" : "URL",
+    "Save" : "Хадгалах",
+    "Translate" : "Орчуулга",
     "to" : "Дуусах нь",
     "Replace" : "Солих",
     "Upload" : "байршуулах",
     "Edit" : "засварлах",
     "Source code" : "эх үүсвэр талын код",
     "Details" : "Дэлгэрэнгүй",
-    "Info" : "Info",
-    "Warning" : "Warning"
+    "Choose" : "Сонгох"
 },
 "nplurals=2; plural=(n != 1);");
