@@ -22,15 +22,6 @@ OC.L10N.register(
     "Text" : "文字編輯器",
     "📝 Collaborative document editing" : "📝 協作文件編輯",
     "** 📝 Collaborative document editing!**\n\n- **📝 Focused writing:** No distractions, only the formatting you need.\n- **🙋 Work together:** Share and collaborate with friends and colleagues, no matter if they use Nextcloud or not!\n- **💾 Open format:** Files are saved as [Markdown](https://en.wikipedia.org/wiki/Markdown), so you can edit them from any other text app too.\n- **✊ Strong foundation:** We use [🐈 tiptap](https://tiptap.scrumpy.io) which is based on [🦉 ProseMirror](https://prosemirror.net) – huge thanks to them!" : "** 📝 協作文件編輯！**\n\n- **📝 聚焦編輯：** 沒有不重要的東西，只有你需要的格式化。\n- **🙋 共同作業：** 與朋友及同事協作，無關他們是否使用 Nextcloud！\n- **💾 開放格式：** 檔案會以 [Markdown]（https://en.wikipedia.org/wiki/Markdown）儲存，所以你也能在其他文字編輯器編輯。\n- **✊ 強大基礎：** 我們使用基於 [🦉 ProseMirror]（https://prosemirror.net）的 [🐈 tiptap]（https://tiptap.scrumpy.io）– 超級感謝他們！",
-    "Insert result" : "插入結果",
-    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
-    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
-    "Nextcloud Assistant" : "Nextcloud 小幫手",
-    "Translate" : "翻譯",
-    "Show assistant results" : "顯示小幫手結果",
-    "Assistant results" : "小幫手結果",
-    "Show result" : "顯示結果",
-    "Delete task" : "刪除任務",
     "Overwrite the file and save the current changes" : "覆寫檔案並保存目前更新",
     "Discard the current changes and load the latest version" : "放棄目前更新並載入最新版本",
     "Reload" : "重新載入",
@@ -41,25 +32,32 @@ OC.L10N.register(
     "This file is opened read-only as it is currently locked by {user}." : "此檔案以唯讀模式打開，因為它目前被 {user} 鎖上。",
     "Close outline view" : "關閉大綱檢視",
     "Outline" : "大綱",
+    "Insert below" : "下方插入",
+    "Click for options, hold to drag" : "點選以檢視選項，按住以拖曳",
+    "Not connected. Cannot update guest name." : "未連接。無法更新訪客名字。",
+    "Failed to update the guest name." : "更新訪客名字失敗",
     "Enter your name so other people can see who is editing" : "輸入您的姓名，以便其他人可以看到誰在編輯",
-    "Edit guest name" : "編輯訪客名稱",
+    "Enter your name" : "輸入您的名稱",
     "Guest" : "訪客",
-    "Save guest name" : "儲存訪客名稱",
+    "submit" : "遞交",
+    "you" : "你",
+    "edit" : "編輯",
     "Uploading multiple attachments failed." : "上傳多個附件失敗。",
     "Uploading attachment failed: {error}" : "上傳附件失敗：{error}",
     "Uploading attachment failed." : "附件上傳失敗。",
     "Insert an attachment" : "插入附件",
     "Failed to insert from Files" : "從檔案插入失敗",
     "Failed to create attachment" : "無法創建附件",
+    "Offline since {time}." : "自 {time} 起離線。",
+    "Not connected to the cloud." : "未連接到雲端。",
     "Preview options" : "預覽選項",
     "Text only" : "僅文字",
     "Show link preview" : "顯示連結預覽",
     "Open in new tab" : "以新分頁打開",
+    "Copy link" : "複製連結",
     "Remove link" : "移除連結",
     "Active people" : "活躍的人",
     "guest" : "訪客",
-    "Full width editor" : "完整寬度編輯器",
-    "Open the Smart Picker" : "打開智能選擇器",
     "Offline" : "離線",
     "Offline, changes will be saved when online" : "離線，在線時更改將被保存",
     "Saving …" : "正在儲存……",
@@ -116,12 +114,13 @@ OC.L10N.register(
     "Redo" : "重作",
     "Toggle outline" : "切換大綱",
     "Alt" : "Alt",
-    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
-    "Copy link to clipboard" : "複製連結到剪貼板",
+    "Open link" : "打開連結",
     "Edit link" : "編輯連結",
     "Save changes" : "保存更改",
     "Cancel" : "取消",
     "URL" : "URL",
+    "Save" : "保存",
+    "Disabled because you are currently offline." : "因為您目前離線，所以已停用。",
     "Attachments cannot be created or uploaded because this file is shared from another cloud." : "無法創建或上傳附件，因為此檔案來自另一個雲端分享。",
     "Upload from computer" : "從電腦上傳",
     "Insert from Files" : "從檔案插入",
@@ -129,12 +128,23 @@ OC.L10N.register(
     "Link to file or folder" : "連結至檔案或資料夾",
     "Link to website" : "連結至網站",
     "Update link" : "更新鏈接",
+    "Open the Smart Picker" : "打開智能選擇器",
     "{menuItemName}, \"{selectedSubMenuItemName}\" is selected" : "{menuItemName}，已選取「{selectedSubMenuItemName}」",
+    "Insert result" : "插入結果",
+    "Nextcloud Assistant result copied" : "已複製 Nextcloud 小幫手結果",
+    "Could not copy result to clipboard" : "無法複製結果至剪貼簿",
+    "Translate" : "翻譯",
+    "Show assistant results" : "顯示小幫手結果",
+    "Assistant results" : "小幫手結果",
+    "Nextcloud Assistant" : "Nextcloud 小幫手",
+    "Show result" : "顯示結果",
+    "Delete task" : "刪除任務",
     "_%n word_::_%n words_" : ["%n 個單詞"],
     "_%n char_::_%n chars_" : ["%n 個字母"],
     "Remaining actions" : "剩餘操作",
     "Editor actions" : "編輯器操作",
     "Formatting menu bar" : "格式化選項單欄",
+    "Full width editor" : "完整寬度編輯器",
     "Translate from {language}" : "從 {language} 翻譯",
     "Translate to {language}" : "翻譯為 {language}",
     "Translation failed" : "翻譯失敗",
@@ -216,17 +226,9 @@ OC.L10N.register(
     "Could not copy to the clipboard" : "無法複製到剪貼簿",
     "Front matter" : "前言",
     "Link to this section" : "連結到本節",
-    "Use current version" : "使用目前版本",
-    "Use the saved version" : "使用儲存版本",
-    "Document has been changed outside of the editor. The changes cannot be applied" : "文件已在編輯器外變更。無法套用變更。",
-    "Document could not be loaded. Please check your internet connection." : "無法載入文件。請檢查您的網路連線。",
-    "Document idle for {timeout} minutes, click to continue editing" : "文件已閒置 {timeout} 分鐘。點選以繼續編輯",
-    "Detect language" : "檢測語言",
-    "Callouts" : "標記",
-    "Info" : "資訊",
-    "Success" : "成功",
-    "Warning" : "警告",
-    "Danger" : "危險",
-    "Start writing, or try '/' to add, '@' to mention…" : "開始撰寫，或試試看「/」新增、「@」提及……"
+    "Edit guest name" : "編輯訪客名稱",
+    "Save guest name" : "儲存訪客名稱",
+    "Cannot copy, please copy the link manually" : "無法複製，請手動複製連結",
+    "Copy link to clipboard" : "複製連結到剪貼板"
 },
 "nplurals=1; plural=0;");
