@@ -27,7 +27,7 @@ OC.L10N.register(
     "%s accessed %s" : "%s је приступио %s",
     "%s renamed %s" : "%s је преименовао %s",
     "%s copied %s" : "%s је копирао %s",
-    "%s assigned %s to %s" : "%s је доделио %s на %s",
+    "%1$s assigned %2$s to %3$s" : "%1$s је доделио %2$s на %3$s",
     "Operation #%s does not exist" : "Операција #%s не постоји",
     "Entity %s does not exist" : "Ентитет %s не постоји",
     "Entity %s is invalid" : "Ентитет %s није исправан",
@@ -56,7 +56,6 @@ OC.L10N.register(
     "PDF documents" : "PDF документи",
     "Video" : "Видео снимак",
     "Custom MIME type" : "Прилагођени MIME тип",
-    "Custom mimetype" : "Произвољни MIME тип",
     "Select a file type" : "Одаберите тип фајла",
     "e.g. httpd/unix-directory" : "нпр. httpd/unix-directory",
     "Please enter a valid time span" : "Унесите исправан временски распон",
