@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Nenalezeno",
     "Node is locked" : "Uzel je uzamčen",
     "Bad request" : "Chybný požadavek",
+    "Input text is too long" : "Vstupní text je příliš dlouhý",
     "Requested task type does not exist" : "Požadovaný typ úkolu neexistuje",
     "Necessary language model provider is not available" : "Nezbytný poskytovatel jazykového modelu není k dsipozici",
     "No text to image provider is available" : "Není k dispozici žádný poskytovatel převodu textu na obrázek",
@@ -262,6 +263,7 @@ OC.L10N.register(
     "An internal error occurred." : "Došlo k vnitřní chybě.",
     "Please try again or contact your administrator." : "Zkuste to znovu nebo se obraťte na správce.",
     "Password" : "Heslo",
+    "Remember me" : "Zapamatovat si mne",
     "Log in with a device" : "Přihlásit se pomocí zařízení",
     "Login or email" : "Přihlašovací jméno nebo e-mail",
     "Your account is not setup for passwordless login." : "Váš účet nemá nastavené přihlašování se bez hesla.",
@@ -285,16 +287,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumenty, tabulky a prezentace pro spolupráci, založené na Collabora Online.",
     "Distraction free note taking app." : "Aplikace pro psaní poznámek bez rozptylování.",
     "Recommended apps" : "Doporučené aplikace",
+    "Loading apps …" : "Načítání aplikací …",
     "Could not fetch list of apps from the App Store." : "Nedaří se získat seznam aplikací z katalogu.",
     "App download or installation failed" : "Stažení aplikace nebo její instalace se nezdařilo",
     "Cannot install this app because it is not compatible" : "Tuto aplikaci nelze nainstalovat, protože není kompatibilní",
     "Cannot install this app" : "Tuto aplikaci nelze nainstalovat",
     "Skip" : "Přeskočit",
+    "Installing apps …" : "Instalace aplikací …",
     "Install recommended apps" : "Nainstalovat doporučené aplikace",
     "Avatar of {displayName}" : "Zástupný obrázek {displayName}",
     "Settings menu" : "Nabídka nastavení",
+    "Loading your contacts …" : "Načítání vašich kontaktů …",
+    "Looking for {term} …" : "Hledání {term} …",
     "Search contacts" : "Hledat v kontaktech",
     "Reset search" : "Resetovat hledání",
+    "Search contacts …" : "Hledat v kontaktech …",
     "Could not load your contacts" : "Nedaří se načíst vaše kontakty",
     "No contacts found" : "Nenalezeny žádné kontakty",
     "Show all contacts" : "Zobrazit všechny kontakty",
@@ -306,6 +313,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Došlo k chybě při hledání pro {type}",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hledání začne jakmile začnete psát a mezi výsledky je možné se pohybovat pomocí klávesami šipka nahoru/dolů",
     "Search for {name} only" : "Hledat pouze {name}",
+    "Loading more results …" : "Načítání dalších výsledků …",
     "Forgot password?" : "Zapomněli jste heslo?",
     "Back to login form" : "Zpět na formulář pro přihlášení",
     "Back" : "Zpět",
@@ -335,6 +343,7 @@ OC.L10N.register(
     "Storage & database" : "Úložiště a databáze",
     "Data folder" : "Složka s daty",
     "Database configuration" : "Nastavení databáze",
+    "Database type" : "Typ databáze",
     "Only {firstAndOnlyDatabase} is available." : "K dispozici je pouze {firstAndOnlyDatabase}.",
     "Install and activate additional PHP modules to choose other database types." : "Pokud chcete vybrat jiné typy databáze, je třeba nainstalovat a povolit dodatečné PHP moduly.",
     "For more details check out the documentation." : "Podrobnosti naleznete v dokumentaci.",
@@ -342,6 +351,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Zvolíte jako databázi SQLite.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite by mělo být použito pouze pro instance, které slouží jen pro vývoj nebo ty obhospodařující opravdu velmi málo dat a uživatelů. Pro jakékoli produkční použití doporučujeme použít robustnější databázové řešení.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Pokud používáte klienty pro synchronizaci souborů, je použití SQLite silně nedoporučeno.",
+    "Database connection" : "Spojení do databáze",
     "Database user" : "Uživatel databáze",
     "Database password" : "Heslo do databáze",
     "Database name" : "Název databáze",
@@ -358,6 +368,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Vámi využívaný webový prohlížeč není podporován. Přejděte na novější verzi nebo na nějaký podporovaný.",
     "Continue with this unsupported browser" : "Pokračovat s tímto zastaralým prohlížečem",
     "Supported versions" : "Podporované verze",
+    "Search {types} …" : "Hledat {types} …",
     "Choose {file}" : "Zvolit {file}",
     "Choose" : "Vybrat",
     "Copy to {target}" : "Zkopírovat do {target}",
