@@ -42,6 +42,7 @@ OC.L10N.register(
     "Not found" : "Nicht gefunden",
     "Node is locked" : "Knoten ist gesperrt",
     "Bad request" : "Fehlerhafte Anfrage",
+    "Input text is too long" : "Eingabetext ist zu lang",
     "Requested task type does not exist" : "Angeforderter Aufgabentyp existiert nicht",
     "Necessary language model provider is not available" : "Erforderlicher Sprachmodellanbieter ist nicht verfügbar",
     "No text to image provider is available" : "Es ist kein Text-zu-Bild-Anbieter verfügbar",
@@ -197,14 +198,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska-Video",
     "Windows Media video" : "Windows Media-Video",
     "AVI video" : "AVI-Video",
-    "unknown text" : "Unbekannter Text",
-    "Hello world!" : "Hallo Welt!",
-    "sunny" : "sonnig",
-    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
-    "Hello {name}" : "Hallo {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
-    "new" : "Neu",
-    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "Die Aktualisierung wird durchgeführt. Wenn du dieses Fenster verlässt, kann dies den Aktualisierungsprozess in manchen Umgebungen unterbrechen.",
     "Update to {version}" : "Aktualisierung auf {version}",
     "An error occurred." : "Es ist ein Fehler aufgetreten.",
@@ -234,7 +227,7 @@ OC.L10N.register(
     "Search in current app" : "In aktueller App suchen ",
     "Clear search" : "Suche löschen",
     "Search everywhere" : "Überall suchen",
-    "Searching …" : "Suche …",
+    "Searching …" : "Suche …",
     "Start typing to search" : "Beginne mit der Eingabe, um zu suchen",
     "Minimum search length is {minSearchLength} characters" : "Die Mindestsuchlänge beträgt {minSearchLength} Zeichen",
     "No matching results" : "Keine passenden Suchergebnisse",
@@ -256,7 +249,7 @@ OC.L10N.register(
     "Load more results" : "Weitere Ergebnisse laden",
     "Search in" : "Suche in",
     "Log in" : "Anmelden",
-    "Logging in …" : "Melde an…",
+    "Logging in …" : "Melde an …",
     "Log in to {productName}" : "Anmelden bei {productName}",
     "Wrong login or password." : "Kontoname oder Passwort falsch",
     "This account is disabled" : "Dieses Konto ist deaktiviert",
@@ -270,6 +263,7 @@ OC.L10N.register(
     "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
     "Please try again or contact your administrator." : "Bitte versuche es noch einmal oder kontaktiere die Administration.",
     "Password" : "Passwort",
+    "Remember me" : "An mich erinnern",
     "Log in with a device" : "Mit einem Gerät anmelden",
     "Login or email" : "Kontoname oder E-Mail-Adresse",
     "Your account is not setup for passwordless login." : "Dein Konto ist nicht für eine Anmeldung ohne Passwort eingerichtet.",
@@ -293,21 +287,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Gemeinsame Dokumente, Tabellenkalkulationen und Präsentationen, die auf Collabora Online basieren.",
     "Distraction free note taking app." : "Ablenkungsfreie Notizen-App",
     "Recommended apps" : "Empfohlene Apps",
-    "Loading apps …" : "Lade Apps …",
+    "Loading apps …" : "Lade Apps …",
     "Could not fetch list of apps from the App Store." : "Liste der Apps konnte nicht vom App-Store abgerufen werden",
     "App download or installation failed" : "Herunterladen oder Installieren der App fehlgeschlagen",
     "Cannot install this app because it is not compatible" : "App kann nicht installiert werden, da sie inkompatibel ist",
     "Cannot install this app" : "App kann nicht installiert werden",
     "Skip" : "Überspringen",
-    "Installing apps …" : "Installiere Apps …",
+    "Installing apps …" : "Installiere Apps …",
     "Install recommended apps" : "Empfohlene Apps installieren",
     "Avatar of {displayName}" : "Avatar von {displayName}",
     "Settings menu" : "Einstellungen-Menü",
-    "Loading your contacts …" : "Lade deine Kontakte …",
-    "Looking for {term} …" : "Suche nach {term} …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
     "Search contacts" : "Kontakte suchen",
     "Reset search" : "Suche zurücksetzen",
-    "Search contacts …" : "Kontakte suchen …",
+    "Search contacts …" : "Kontakte suchen …",
     "Could not load your contacts" : "Deine Kontakte konnten nicht geladen werden",
     "No contacts found" : "Keine Kontakte gefunden",
     "Show all contacts" : "Alle Kontakte anzeigen",
@@ -319,7 +313,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "Es ist ein Fehler beim Suchen nach {type} aufgetreten",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Die Suche beginnt, sobald du mit der Eingabe beginnst. Die Suchergebnisse kannst du mit den Pfeiltasten auswählen,",
     "Search for {name} only" : "Nur nach {name} suchen",
-    "Loading more results …" : "Lade weitere Ergebnisse …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
     "Forgot password?" : "Passwort vergessen?",
     "Back to login form" : "Zurück zum Anmeldeformular",
     "Back" : "Zurück",
@@ -341,7 +335,7 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the <code>.htaccess</code> file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich über das Internet zugänglich, da die <code>.htaccess</code>-Datei nicht funktioniert.",
     "For information how to properly configure your server, please {linkStart}see the documentation{linkEnd}" : "Informationen zur ordnungsgemäßen Konfiguration des Servers sind {linkStart}in der Dokumentation zu finden{linkEnd}",
     "Autoconfig file detected" : "Autoconfig-Datei erkannt",
-    "The setup form below is pre-filled with the values from the config file." : "Das folgende Setup-Formular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
+    "The setup form below is pre-filled with the values from the config file." : "Das folgende Einrichtungsformular ist mit den Werten aus der Konfigurationsdatei vorausgefüllt.",
     "Security warning" : "Sicherheitswarnung",
     "Create administration account" : "Administrationskonto erstellen",
     "Administration account name" : "Name des Administrationskontos",
@@ -349,6 +343,7 @@ OC.L10N.register(
     "Storage & database" : "Speicher & Datenbank",
     "Data folder" : "Datenverzeichnis",
     "Database configuration" : "Datenbankkonfiguration",
+    "Database type" : "Datenbank-Typ",
     "Only {firstAndOnlyDatabase} is available." : "Nur {firstAndOnlyDatabase} ist verfügbar",
     "Install and activate additional PHP modules to choose other database types." : "Um weitere Datenbank-Typen auswählen zu können, müssen zusätzliche PHP-Module installiert und aktiviert werden.",
     "For more details check out the documentation." : "Schau für weitere Informationen in die Dokumentation.",
@@ -356,6 +351,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "Du hast SQLite als Datenbanktyp ausgewählt.",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite sollte nur für Minimal- und Entwicklungsinstanzen gewählt werden. Für die Produktion wird ein anderes Datenbank-Backend empfohlen.",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "Wenn Clients für die Dateisynchronisierung verwenden werden, so wird von der Verwendung von SQLite dringend abgeraten.",
+    "Database connection" : "Datenbankverbindung",
     "Database user" : "Datenbank-Benutzer",
     "Database password" : "Datenbank-Passwort",
     "Database name" : "Datenbank-Name",
@@ -363,7 +359,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "Bitte die Portnummer mit der Hostadresse zusammen angeben (z. B. localhost:5432)",
     "Database host" : "Datenbank-Host",
     "localhost" : "localhost",
-    "Installing …" : "Installiere …",
+    "Installing …" : "Installiere …",
     "Install" : "Installieren",
     "Need help?" : "Hilfe nötig?",
     "See the documentation" : "Schau in die Dokumentation",
@@ -372,7 +368,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Dein Browser wird nicht unterstützt. Bitte aktualisieren deinen Browser auf eine neuere oder unterstützte Version.",
     "Continue with this unsupported browser" : "Mit diesem nicht unterstützten Browser fortfahren.",
     "Supported versions" : "Unterstützte Versionen",
-    "Search {types} …" : "Suche {types} …",
+    "Search {types} …" : "Suche {types} …",
     "Choose {file}" : "{file} auswählen",
     "Choose" : "Auswählen",
     "Copy to {target}" : "Nach {target} kopieren",
@@ -392,7 +388,7 @@ OC.L10N.register(
     "(all selected)" : "(Alle ausgewählt)",
     "({count} selected)" : "({count} ausgewählt)",
     "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
-    "Saving …" : "Speichern …",
+    "Saving …" : "Speichere …",
     "seconds ago" : "Gerade eben",
     "Connection to server lost" : "Verbindung zum Server verloren",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Problem beim Laden der Seite, Seite wird in %n Sekunde nochmals geladen","Problem beim Laden der Seite, Seite wird in %n Sekunden erneut geladen"],
@@ -407,8 +403,6 @@ OC.L10N.register(
     "Type to search for existing projects" : "Nach existierenden Projekten suchen",
     "New in" : "Neu in",
     "View changelog" : "Liste der Veränderungen ansehen",
-    "No action available" : "Keine Aktion verfügbar",
-    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Close \"{dialogTitle}\" dialog" : "Dialog \"{dialogTitle}\" schließen",
     "Email length is at max (255)" : "Maximale Länge der E-Mail-Adresse erreicht (255)",
     "Clipboard not available, please copy manually" : "Zwischenablage nicht verfügbar, bitte manuell kopieren",
@@ -476,7 +470,7 @@ OC.L10N.register(
     "Enhanced security is enforced for your account. Choose which provider to set up:" : "Erhöhte Sicherheit ist für dein Konto aktiviert. Bitte wähle einen Anbieter zum Einrichten: ",
     "Error while validating your second factor" : "Fehler beim Bestätigen des zweiten Sicherheitsfaktors",
     "Access through untrusted domain" : "Zugriff über eine nicht vertrauenswürdige Domain",
-    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deine Administration. Wenn du Administrator bist,  bearbeite die \"trusted_domains\"-Einstellung in config/config.php. Siehe Beispiel in config/config.sample.php.",
+    "Please contact your administrator. If you are an administrator, edit the \"trusted_domains\" setting in config/config.php like the example in config.sample.php." : "Bitte kontaktiere deine Administration. Wenn du der Administration angehörst,  bearbeite die \"trusted_domains\"-Einstellung in config/config.php. Siehe Beispiel in config/config.sample.php.",
     "Further information how to configure this can be found in the %1$sdocumentation%2$s." : "Weitere Informationen zur Konfiguration finden sich in der %1$sDokumentation%2$s.",
     "App update required" : "App-Aktualisierung notwendig",
     "%1$s will be updated to version %2$s" : "%1$s wird auf Version %2$s aktualisiert",
@@ -496,23 +490,34 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Diese Instanz der %s - befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
     "This page will refresh itself when the instance is available again." : "Diese Seite aktualisiert sich automatisch, sobald diese Instanz wieder verfügbar ist.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere die Systemadministration, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
-    "No temporary profile picture available, try again" : "Kein temporäres Profilbild verfügbar, bitte versuche es noch einmal",
-    "No crop data provided" : "Keine Beschnittdaten zur Verfügung gestellt",
-    "No valid crop data provided" : "Keine gültigen Zuschnittdaten zur Verfügung gestellt",
-    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
     "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
     "For more details see the {linkstart}documentation ↗{linkend}." : "Weitere Informationen findest du in der {linkstart}Dokumentation ↗{linkend}.",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatten, Videoanrufe, Bildschirmfreigaben, Online-Besprechungen und Webkonferenzen - in deinem Browser sowie mit mobilen Apps.",
-    "You have not added any info yet" : "Du hast noch keine Infos hinzugefügt",
-    "{user} has not added any info yet" : "{user} hat noch keine Infos hinzugefügt",
-    "Error opening the user status modal, try hard refreshing the page" : "Fehler beim Modal-öffnen des Benutzerstatus, versuche die Seite zu aktualisieren",
-    "Edit Profile" : "Profil bearbeiten",
-    "The headline and about sections will show up here" : "Die Überschrift und der Infobereich werden hier angezeigt",
+    "unknown text" : "Unbekannter Text",
+    "Hello world!" : "Hallo Welt!",
+    "sunny" : "sonnig",
+    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
+    "Hello {name}" : "Hallo {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Dies sind deine Suchergebnisse<script>alert(1)</script></strong>",
+    "new" : "Neu",
+    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
+    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert",
+    "Searching …" : "Suche …",
+    "Logging in …" : "Melde an…",
+    "Loading apps …" : "Lade Apps …",
+    "Installing apps …" : "Installiere Apps …",
+    "Loading your contacts …" : "Lade deine Kontakte …",
+    "Looking for {term} …" : "Suche nach {term} …",
+    "Search contacts …" : "Kontakte suchen …",
+    "Loading more results …" : "Lade weitere Ergebnisse …",
+    "Search {types} …" : "Suche {types} …",
+    "Saving …" : "Speichern …",
     "Very weak password" : "Sehr schwaches Passwort",
     "Weak password" : "Schwaches Passwort",
     "So-so password" : "Passables Passwort",
     "Good password" : "Gutes Passwort",
     "Strong password" : "Starkes Passwort",
+    "No action available" : "Keine Aktion verfügbar",
+    "Error fetching contact actions" : "Fehler beim Einlesen der Kontakt-Aktionen",
     "Non-existing tag #{tag}" : "Nicht existierender Tag #{tag}",
     "Restricted" : "Eingeschränkt",
     "Invisible" : "Unsichtbar",
@@ -520,8 +525,6 @@ OC.L10N.register(
     "Rename" : "Umbenennen",
     "Collaborative tags" : "Kollaborative Schlagworte",
     "No tags found" : "Keine Tags gefunden",
-    "Profile not found" : "Profil nicht gefunden",
-    "The profile does not exist." : "Das Profil existiert nicht",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Dein Datenverzeichnis und deine Dateien sind wahrscheinlich vom Internet aus erreichbar, weil die .htaccess-Datei nicht funktioniert.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Informationen zum richtigen Konfigurieren deines Servers kannst du der <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">Dokumentation</a> entnehmen.",
     "<strong>Create an admin account</strong>" : "<strong>Administrationskonto anlegen</strong>",
@@ -532,6 +535,6 @@ OC.L10N.register(
     "Configure the database" : "Datenbank einrichten",
     "Only %s is available." : "Es ist nur %s verfügbar.",
     "Database account" : "Datenbankkonto",
-    "Direct link copied to clipboard" : "Direkter Link in die Zwischenablage kopiert"
+    "Installing …" : "Installiere …"
 },
 "nplurals=2; plural=(n != 1);");
