@@ -18,10 +18,6 @@ OC.L10N.register(
     "Unknown filetype" : "未知的文件类型",
     "An error occurred. Please contact your admin." : "发生了错误，请联系管理员。",
     "Invalid image" : "无效的图片",
-    "No temporary profile picture available, try again" : "没有临时个人页图片可用，请重试",
-    "No crop data provided" : "没有提供剪裁数据",
-    "No valid crop data provided" : "没有提供有效的裁剪数据",
-    "Crop is not square" : "裁剪的不是正方形",
     "State token does not match" : "状态令牌无法匹配",
     "Invalid app password" : "无效的应用密码",
     "Could not complete login" : "无法完成登录",
@@ -53,6 +49,7 @@ OC.L10N.register(
     "No translation provider available" : "没有可用的翻译提供程序",
     "Could not detect language" : "无法检测语言",
     "Unable to translate" : "无法翻译",
+    "No valid filters provided" : "未提供有效的筛选",
     "[%d / %d]: %s" : "[%d / %d]：%s",
     "Repair step:" : "修复日志 步骤：",
     "Repair info:" : "修复 信息：",
@@ -200,14 +197,6 @@ OC.L10N.register(
     "Matroska video" : "Matroska 视频",
     "Windows Media video" : "Windows 媒体视频",
     "AVI video" : "AVI 视频",
-    "unknown text" : "未知文字",
-    "Hello world!" : "你好，世界！",
-    "sunny" : "晴",
-    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是 {weather}",
-    "Hello {name}" : "您好 {name}",
-    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>警告（1）</script></strong>",
-    "new" : "新建",
-    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "正在更新，在某些环境下离开当前页面可能会中断。",
     "Update to {version}" : "升级到 {version}",
     "An error occurred." : "发生错误。",
@@ -236,15 +225,17 @@ OC.L10N.register(
     "Search in date range" : "在日期范围内进行搜索",
     "Search in current app" : "在当前应用程序中搜索",
     "Clear search" : "清除搜索",
-    "Search everywhere" : "在所有位置搜索",
-    "Searching …" : "正在搜索 ...",
+    "Search everywhere" : "全局搜索",
+    "Searching …" : "正在搜索 …",
     "Start typing to search" : "开始输入以搜索",
+    "Minimum search length is {minSearchLength} characters" : "最小搜索长度为 {minSearchLength} 个字符",
     "No matching results" : "无匹配结果",
     "Today" : "今日",
     "Last 7 days" : "过去 7 天",
     "Last 30 days" : "过去 30 天",
     "This year" : "今年",
     "Last year" : "去年",
+    "Between {startDate} and {endDate}" : "{startDate} 和 {endDate} 之间",
     "Unified search" : "统一搜索",
     "Search apps, files, tags, messages" : "搜索应用程序、文件、标签，信息",
     "Places" : "位置",
@@ -257,7 +248,7 @@ OC.L10N.register(
     "Load more results" : "加载更多结果",
     "Search in" : "搜索",
     "Log in" : "登录",
-    "Logging in …" : "正在登录……",
+    "Logging in …" : "正在登录 …",
     "Log in to {productName}" : "登录到 {productName}",
     "Wrong login or password." : "账号或密码错误",
     "This account is disabled" : "此账号已停用",
@@ -294,21 +285,21 @@ OC.L10N.register(
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "基于 Collabora Online 的文档、表格与演示文档。",
     "Distraction free note taking app." : "无干扰的笔记记录应用。",
     "Recommended apps" : "推荐的应用",
-    "Loading apps …" : "正在加载应用…",
+    "Loading apps …" : "正在加载应用 …",
     "Could not fetch list of apps from the App Store." : "无法从应用商店获取应用列表",
     "App download or installation failed" : "应用下载或安装失败",
     "Cannot install this app because it is not compatible" : "无法安装此应用，因它不兼容",
     "Cannot install this app" : "无法安装此应用",
     "Skip" : "跳过",
-    "Installing apps …" : "正在安装应用...",
+    "Installing apps …" : "正在安装应用 …",
     "Install recommended apps" : "安装推荐的应用",
     "Avatar of {displayName}" : "{displayName} 的头像",
     "Settings menu" : "设置菜单",
-    "Loading your contacts …" : "正在加载您的联系人……",
-    "Looking for {term} …" : "正在查找{term} ……",
+    "Loading your contacts …" : "正在加载您的联系人 …",
+    "Looking for {term} …" : "正在寻找 {term} …",
     "Search contacts" : "搜索联系人",
     "Reset search" : "重置搜索",
-    "Search contacts …" : "搜索联系人……",
+    "Search contacts …" : "搜索联系人 …",
     "Could not load your contacts" : "无法加载您的联系人",
     "No contacts found" : "无法找到联系人",
     "Show all contacts" : "显示所有联系人",
@@ -320,7 +311,7 @@ OC.L10N.register(
     "An error occurred while searching for {type}" : "搜索 {type} 时出错",
     "Search starts once you start typing and results may be reached with the arrow keys" : "一旦开始输入，搜索就会开始，你可以使用方向键切换到结果。",
     "Search for {name} only" : "仅搜索 {name}",
-    "Loading more results …" : "加载更多结果...",
+    "Loading more results …" : "正在加载更多结果 …",
     "Forgot password?" : "忘记密码？",
     "Back to login form" : "回到登录表单",
     "Back" : "返回",
@@ -350,6 +341,7 @@ OC.L10N.register(
     "Storage & database" : "存储与数据库",
     "Data folder" : "数据目录",
     "Database configuration" : "数据库配置",
+    "Database type" : "数据库类型",
     "Only {firstAndOnlyDatabase} is available." : "只有 {firstAndOnlyDatabase} 可用。",
     "Install and activate additional PHP modules to choose other database types." : "安装并激活额外的 PHP 模块以选择其他数据库类型。",
     "For more details check out the documentation." : "请查阅文档获得详细信息。",
@@ -357,6 +349,7 @@ OC.L10N.register(
     "You chose SQLite as database." : "您选择 SQLite 作为数据库。",
     "SQLite should only be used for minimal and development instances. For production we recommend a different database backend." : "SQLite 应只用于最小化和开发实例。生产环境我们推荐使用不同的数据库后端。",
     "If you use clients for file syncing, the use of SQLite is highly discouraged." : "如果您使用文件同步客户端，强烈不建议使用 SQLite。",
+    "Database connection" : "数据库连接",
     "Database user" : "数据库用户",
     "Database password" : "数据库密码",
     "Database name" : "数据库名",
@@ -364,7 +357,7 @@ OC.L10N.register(
     "Please specify the port number along with the host name (e.g., localhost:5432)." : "请填写主机名称和端口号（例如，localhost:5432）。",
     "Database host" : "数据库主机",
     "localhost" : "本地主机",
-    "Installing …" : "正在安装...",
+    "Installing …" : "正在安装 …",
     "Install" : "安装",
     "Need help?" : "需要帮助？",
     "See the documentation" : "查看文档",
@@ -373,7 +366,7 @@ OC.L10N.register(
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "您的浏览器不受支持。请升级至较新或受支持的版本。",
     "Continue with this unsupported browser" : "继续使用该过时的浏览器",
     "Supported versions" : "支持的版本",
-    "Search {types} …" : "搜索 {types} …",
+    "Search {types} …" : "搜索 {types} …",
     "Choose {file}" : "选择 {file}",
     "Choose" : "选择",
     "Copy to {target}" : "复制到 {target}",
@@ -393,7 +386,7 @@ OC.L10N.register(
     "(all selected)" : "（选中全部）",
     "({count} selected)" : "（选择了 {count} 个）",
     "Error loading file exists template" : "加载文件存在性模板失败",
-    "Saving …" : "正在保存…",
+    "Saving …" : "正在保存 …",
     "seconds ago" : "几秒前",
     "Connection to server lost" : "与服务器的连接断开",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["加载页面出现问题，将在%n秒后重新加载"],
@@ -408,17 +401,8 @@ OC.L10N.register(
     "Type to search for existing projects" : "输入以搜索已有项目",
     "New in" : "新品",
     "View changelog" : "查看更新记录",
-    "No action available" : "无可用操作",
-    "Error fetching contact actions" : "查找联系人时出错",
     "Close \"{dialogTitle}\" dialog" : "关闭“{dialogTitle}”对话",
     "Email length is at max (255)" : "邮箱长度达到最大（255）",
-    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
-    "Restricted" : "受限",
-    "Invisible" : "隐藏",
-    "Delete" : "删除",
-    "Rename" : "重命名",
-    "Collaborative tags" : "协作标签",
-    "No tags found" : "标签未找到",
     "Clipboard not available, please copy manually" : "剪贴板不可用，请手动复制",
     "Personal" : "个人",
     "Accounts" : "账号",
@@ -506,19 +490,39 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "如果这个消息一直存在或不停出现，请联系您的系统管理员。",
     "Error occurred while checking server setup" : "检查服务器设置时出错",
     "For more details see the {linkstart}documentation ↗{linkend}." : "了解更多详情，请参见{linkstart}文档 ↗{linkend}。",
-    "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "在浏览器和移动设备应用中进行聊天，视频通话，屏幕共享，线上见面和网络会议。",
-    "You have not added any info yet" : "您尚未添加任何信息",
-    "{user} has not added any info yet" : "{user} 尚未添加任何信息",
-    "Error opening the user status modal, try hard refreshing the page" : "打开用户状态模块时出错，请努力刷新页面",
-    "Edit Profile" : "编辑个人资料",
-    "The headline and about sections will show up here" : "标题和关于部分将显示在此处",
+    "unknown text" : "未知文字",
+    "Hello world!" : "你好，世界！",
+    "sunny" : "晴",
+    "Hello {name}, the weather is {weather}" : "您好 {name}，今天天气是 {weather}",
+    "Hello {name}" : "您好 {name}",
+    "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>这是您的搜索结果<script>警告（1）</script></strong>",
+    "new" : "新建",
+    "_download %n file_::_download %n files_" : ["下载 %n 个文件"],
+    "Direct link copied to clipboard" : "直链已复制至粘贴板",
+    "Searching …" : "正在搜索 ...",
+    "Logging in …" : "正在登录……",
+    "Loading apps …" : "正在加载应用…",
+    "Installing apps …" : "正在安装应用...",
+    "Loading your contacts …" : "正在加载您的联系人……",
+    "Looking for {term} …" : "正在查找{term} ……",
+    "Search contacts …" : "搜索联系人……",
+    "Loading more results …" : "加载更多结果...",
+    "Search {types} …" : "搜索 {types} …",
+    "Saving …" : "正在保存…",
     "Very weak password" : "非常弱的密码",
     "Weak password" : "弱密码",
     "So-so password" : "一般强度的密码",
     "Good password" : "较强的密码",
     "Strong password" : "强密码",
-    "Profile not found" : "未找到个人资料",
-    "The profile does not exist." : "个人资料不存在",
+    "No action available" : "无可用操作",
+    "Error fetching contact actions" : "查找联系人时出错",
+    "Non-existing tag #{tag}" : "标签 #{tag} 不存在",
+    "Restricted" : "受限",
+    "Invisible" : "隐藏",
+    "Delete" : "删除",
+    "Rename" : "重命名",
+    "Collaborative tags" : "协作标签",
+    "No tags found" : "标签未找到",
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "因为 .htaccess 文件没有工作，您的数据目录和文件可从互联网被访问。",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "关于如何正确配置服务器，请参见<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">文档</a>。",
     "<strong>Create an admin account</strong>" : "<strong>创建管理员账号</strong>",
@@ -529,6 +533,6 @@ OC.L10N.register(
     "Configure the database" : "配置数据库",
     "Only %s is available." : "仅 %s 可用。",
     "Database account" : "数据库账号",
-    "Direct link copied to clipboard" : "直链已复制至粘贴板"
+    "Installing …" : "正在安装..."
 },
 "nplurals=1; plural=0;");
