@@ -11,16 +11,21 @@ namespace OC;
 
 use InvalidArgumentException;
 use JsonException;
-use NCU\Config\Lexicon\ConfigLexiconEntry;
-use NCU\Config\Lexicon\ConfigLexiconStrictness;
-use NCU\Config\Lexicon\IConfigLexicon;
 use OC\AppFramework\Bootstrap\Coordinator;
+use OC\Config\ConfigManager;
+use OC\Config\PresetManager;
+use OC\Memcache\Factory as CacheFactory;
+use OCP\Config\Lexicon\Entry;
+use OCP\Config\Lexicon\Strictness;
+use OCP\Config\ValueType;
 use OCP\DB\Exception as DBException;
 use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\Exceptions\AppConfigIncorrectTypeException;
 use OCP\Exceptions\AppConfigTypeConflictException;
 use OCP\Exceptions\AppConfigUnknownKeyException;
 use OCP\IAppConfig;
+use OCP\ICache;
+use OCP\ICacheFactory;
 use OCP\IConfig;
 use OCP\IDBConnection;
 use OCP\Security\ICrypto;
@@ -50,33 +55,40 @@ class AppConfig implements IAppConfig {
 	private const KEY_MAX_LENGTH = 64;
 	private const ENCRYPTION_PREFIX = '$AppConfigEncryption$';
 	private const ENCRYPTION_PREFIX_LENGTH = 21; // strlen(self::ENCRYPTION_PREFIX)
+	private const LOCAL_CACHE_KEY = 'OC\\AppConfig';
+	private const LOCAL_CACHE_TTL = 3;
 
-	/** @var array<string, array<string, mixed>> ['app_id' => ['config_key' => 'config_value']] */
+	/** @var array<string, array<string, string>> ['app_id' => ['config_key' => 'config_value']] */
 	private array $fastCache = [];   // cache for normal config keys
-	/** @var array<string, array<string, mixed>> ['app_id' => ['config_key' => 'config_value']] */
+	/** @var array<string, array<string, string>> ['app_id' => ['config_key' => 'config_value']] */
 	private array $lazyCache = [];   // cache for lazy config keys
 	/** @var array<string, array<string, int>> ['app_id' => ['config_key' => bitflag]] */
 	private array $valueTypes = [];  // type for all config values
 	private bool $fastLoaded = false;
 	private bool $lazyLoaded = false;
-	/** @var array<array-key, array{entries: array<array-key, ConfigLexiconEntry>, strictness: ConfigLexiconStrictness}> ['app_id' => ['strictness' => ConfigLexiconStrictness, 'entries' => ['config_key' => ConfigLexiconEntry[]]] */
+	/** @var array<string, array{entries: array<string, Entry>, aliases: array<string, string>, strictness: Strictness}> ['app_id' => ['strictness' => ConfigLexiconStrictness, 'entries' => ['config_key' => ConfigLexiconEntry[]]] */
 	private array $configLexiconDetails = [];
+	private bool $ignoreLexiconAliases = false;
+	private array $strictnessApplied = [];
 
-	/**
-	 * $migrationCompleted is only needed to manage the previous structure
-	 * of the database during the upgrading process to nc29.
-	 *
-	 * only when upgrading from a version prior 28.0.2
-	 *
-	 * @TODO: remove this value in Nextcloud 30+
-	 */
-	private bool $migrationCompleted = true;
+	/** @var ?array<string, string> */
+	private ?array $appVersionsCache = null;
+	private ?ICache $localCache = null;
 
 	public function __construct(
 		protected IDBConnection $connection,
+		protected IConfig $config,
+		private readonly ConfigManager $configManager,
+		private readonly PresetManager $presetManager,
 		protected LoggerInterface $logger,
 		protected ICrypto $crypto,
+		readonly CacheFactory $cacheFactory,
 	) {
+		if ($config->getSystemValueBool('cache_app_config', true) && $cacheFactory->isLocalCacheAvailable()) {
+			$cacheFactory->withServerVersionPrefix(function (ICacheFactory $factory) {
+				$this->localCache = $factory->createLocal();
+			});
+		}
 	}
 
 	/**
@@ -86,7 +98,7 @@ class AppConfig implements IAppConfig {
 	 * @since 7.0.0
 	 */
 	public function getApps(): array {
-		$this->loadConfigAll();
+		$this->loadConfig(lazy: true);
 		$apps = array_merge(array_keys($this->fastCache), array_keys($this->lazyCache));
 		sort($apps);
 
@@ -98,12 +110,13 @@ class AppConfig implements IAppConfig {
 	 *
 	 * @param string $app id of the app
 	 * @return list<string> list of stored config keys
+	 * @see searchKeys to not load lazy config keys
 	 *
 	 * @since 29.0.0
 	 */
 	public function getKeys(string $app): array {
 		$this->assertParams($app);
-		$this->loadConfigAll($app);
+		$this->loadConfig($app, true);
 		$keys = array_merge(array_keys($this->fastCache[$app] ?? []), array_keys($this->lazyCache[$app] ?? []));
 		sort($keys);
 
@@ -118,7 +131,6 @@ class AppConfig implements IAppConfig {
 	 * @param bool $lazy TRUE to search in lazy config keys
 	 * @return list<string> list of stored config keys
 	 * @since 32.0.0
-	 * @internal not publicly available before 32.
 	 */
 	public function searchKeys(string $app, string $prefix = '', bool $lazy = false): array {
 		$this->assertParams($app);
@@ -150,18 +162,16 @@ class AppConfig implements IAppConfig {
 	 */
 	public function hasKey(string $app, string $key, ?bool $lazy = false): bool {
 		$this->assertParams($app, $key);
-		$this->loadConfig($app, $lazy);
+		$this->loadConfig($app, $lazy ?? true);
+		$this->matchAndApplyLexiconDefinition($app, $key);
 
+		$hasLazy = isset($this->lazyCache[$app][$key]);
+		$hasFast = isset($this->fastCache[$app][$key]);
 		if ($lazy === null) {
-			$appCache = $this->getAllValues($app);
-			return isset($appCache[$key]);
+			return $hasLazy || $hasFast;
+		} else {
+			return $lazy ? $hasLazy : $hasFast;
 		}
-
-		if ($lazy) {
-			return isset($this->lazyCache[$app][$key]);
-		}
-
-		return isset($this->fastCache[$app][$key]);
 	}
 
 	/**
@@ -175,7 +185,8 @@ class AppConfig implements IAppConfig {
 	 */
 	public function isSensitive(string $app, string $key, ?bool $lazy = false): bool {
 		$this->assertParams($app, $key);
-		$this->loadConfig(null, $lazy);
+		$this->loadConfig(null, $lazy ?? true);
+		$this->matchAndApplyLexiconDefinition($app, $key);
 
 		if (!isset($this->valueTypes[$app][$key])) {
 			throw new AppConfigUnknownKeyException('unknown config key');
@@ -196,6 +207,9 @@ class AppConfig implements IAppConfig {
 	 * @since 29.0.0
 	 */
 	public function isLazy(string $app, string $key): bool {
+		$this->assertParams($app, $key);
+		$this->matchAndApplyLexiconDefinition($app, $key);
+
 		// there is a huge probability the non-lazy config are already loaded
 		if ($this->hasKey($app, $key, false)) {
 			return false;
@@ -223,7 +237,7 @@ class AppConfig implements IAppConfig {
 	public function getAllValues(string $app, string $prefix = '', bool $filtered = false): array {
 		$this->assertParams($app, $prefix);
 		// if we want to filter values, we need to get sensitivity
-		$this->loadConfigAll($app);
+		$this->loadConfig($app, true);
 		// array_merge() will remove numeric keys (here config keys), so addition arrays instead
 		$values = $this->formatAppValues($app, ($this->fastCache[$app] ?? []) + ($this->lazyCache[$app] ?? []));
 		$values = array_filter(
@@ -318,7 +332,7 @@ class AppConfig implements IAppConfig {
 	): string {
 		try {
 			$lazy = ($lazy === null) ? $this->isLazy($app, $key) : $lazy;
-		} catch (AppConfigUnknownKeyException $e) {
+		} catch (AppConfigUnknownKeyException) {
 			return $default;
 		}
 
@@ -463,10 +477,19 @@ class AppConfig implements IAppConfig {
 		int $type,
 	): string {
 		$this->assertParams($app, $key, valueType: $type);
-		if (!$this->matchAndApplyLexiconDefinition($app, $key, $lazy, $type, $default)) {
-			return $default; // returns default if strictness of lexicon is set to WARNING (block and report)
+		$origKey = $key;
+		$matched = $this->matchAndApplyLexiconDefinition($app, $key, $lazy, $type, $default);
+		if ($default === null) {
+			// there is no logical reason for it to be null
+			throw new \Exception('default cannot be null');
 		}
-		$this->loadConfig($app, $lazy);
+
+		// returns default if strictness of lexicon is set to WARNING (block and report)
+		if (!$matched) {
+			return $default;
+		}
+
+		$this->loadConfig($app, $lazy ?? true);
 
 		/**
 		 * We ignore check if mixed type is requested.
@@ -503,6 +526,13 @@ class AppConfig implements IAppConfig {
 			$value = $this->crypto->decrypt(substr($value, self::ENCRYPTION_PREFIX_LENGTH));
 		}
 
+		// in case the key was modified while running matchAndApplyLexiconDefinition() we are
+		// interested to check options in case a modification of the value is needed
+		// ie inverting value from previous key when using lexicon option RENAME_INVERT_BOOLEAN
+		if ($origKey !== $key && $type === self::VALUE_BOOL) {
+			$value = ($this->configManager->convertToBool($value, $this->getLexiconEntry($app, $key))) ? '1' : '0';
+		}
+
 		return $value;
 	}
 
@@ -522,8 +552,16 @@ class AppConfig implements IAppConfig {
 	 * @see VALUE_ARRAY
 	 */
 	public function getValueType(string $app, string $key, ?bool $lazy = null): int {
+		$type = self::VALUE_MIXED;
+		$ignorable = $lazy ?? false;
+		$this->matchAndApplyLexiconDefinition($app, $key, $ignorable, $type);
+		if ($type !== self::VALUE_MIXED) {
+			// a modified $type means config key is set in Lexicon
+			return $type;
+		}
+
 		$this->assertParams($app, $key);
-		$this->loadConfig($app, $lazy);
+		$this->loadConfig($app, $lazy ?? true);
 
 		if (!isset($this->valueTypes[$app][$key])) {
 			throw new AppConfigUnknownKeyException('unknown config key');
@@ -760,7 +798,7 @@ class AppConfig implements IAppConfig {
 		if (!$this->matchAndApplyLexiconDefinition($app, $key, $lazy, $type)) {
 			return false; // returns false as database is not updated
 		}
-		$this->loadConfig(null, $lazy);
+		$this->loadConfig(null, $lazy ?? true);
 
 		$sensitive = $this->isTyped(self::VALUE_SENSITIVE, $type);
 		$inserted = $refreshCache = false;
@@ -775,7 +813,7 @@ class AppConfig implements IAppConfig {
 			 * no update if key is already known with set lazy status and value is
 			 * not different, unless sensitivity is switched from false to true.
 			 */
-			if ($origValue === $this->getTypedValue($app, $key, $value, $lazy, $type)
+			if ($origValue === $this->getTypedValue($app, $key, $value, $lazy ?? true, $type)
 				&& (!$sensitive || $this->isSensitive($app, $key, $lazy))) {
 				return false;
 			}
@@ -807,7 +845,7 @@ class AppConfig implements IAppConfig {
 		if (!$inserted) {
 			$currType = $this->valueTypes[$app][$key] ?? 0;
 			if ($currType === 0) { // this might happen when switching lazy loading status
-				$this->loadConfigAll();
+				$this->loadConfig(lazy: true);
 				$currType = $this->valueTypes[$app][$key] ?? 0;
 			}
 
@@ -824,8 +862,8 @@ class AppConfig implements IAppConfig {
 			 * we only accept a different type from the one stored in database
 			 * if the one stored in database is not-defined (VALUE_MIXED)
 			 */
-			if (!$this->isTyped(self::VALUE_MIXED, $currType) &&
-				($type | self::VALUE_SENSITIVE) !== ($currType | self::VALUE_SENSITIVE)) {
+			if (!$this->isTyped(self::VALUE_MIXED, $currType)
+				&& ($type | self::VALUE_SENSITIVE) !== ($currType | self::VALUE_SENSITIVE)) {
 				try {
 					$currType = $this->convertTypeToString($currType);
 					$type = $this->convertTypeToString($type);
@@ -871,6 +909,7 @@ class AppConfig implements IAppConfig {
 			$this->fastCache[$app][$key] = $value;
 		}
 		$this->valueTypes[$app][$key] = $type;
+		$this->clearLocalCache();
 
 		return true;
 	}
@@ -892,8 +931,9 @@ class AppConfig implements IAppConfig {
 	 */
 	public function updateType(string $app, string $key, int $type = self::VALUE_MIXED): bool {
 		$this->assertParams($app, $key);
-		$this->loadConfigAll();
-		$lazy = $this->isLazy($app, $key);
+		$this->loadConfig(lazy: true);
+		$this->matchAndApplyLexiconDefinition($app, $key);
+		$this->isLazy($app, $key); // confirm key exists
 
 		// type can only be one type
 		if (!in_array($type, [self::VALUE_MIXED, self::VALUE_STRING, self::VALUE_INT, self::VALUE_FLOAT, self::VALUE_BOOL, self::VALUE_ARRAY])) {
@@ -934,7 +974,8 @@ class AppConfig implements IAppConfig {
 	 */
 	public function updateSensitive(string $app, string $key, bool $sensitive): bool {
 		$this->assertParams($app, $key);
-		$this->loadConfigAll();
+		$this->loadConfig(lazy: true);
+		$this->matchAndApplyLexiconDefinition($app, $key);
 
 		try {
 			if ($sensitive === $this->isSensitive($app, $key, null)) {
@@ -993,7 +1034,8 @@ class AppConfig implements IAppConfig {
 	 */
 	public function updateLazy(string $app, string $key, bool $lazy): bool {
 		$this->assertParams($app, $key);
-		$this->loadConfigAll();
+		$this->loadConfig(lazy: true);
+		$this->matchAndApplyLexiconDefinition($app, $key);
 
 		try {
 			if ($lazy === $this->isLazy($app, $key)) {
@@ -1028,7 +1070,8 @@ class AppConfig implements IAppConfig {
 	 */
 	public function getDetails(string $app, string $key): array {
 		$this->assertParams($app, $key);
-		$this->loadConfigAll();
+		$this->loadConfig(lazy: true);
+		$this->matchAndApplyLexiconDefinition($app, $key);
 		$lazy = $this->isLazy($app, $key);
 
 		if ($lazy) {
@@ -1066,6 +1109,49 @@ class AppConfig implements IAppConfig {
 		];
 	}
 
+	/**
+	 * @inheritDoc
+	 *
+	 * @param string $app id of the app
+	 * @param string $key config key
+	 *
+	 * @return array{app: string, key: string, lazy?: bool, valueType?: ValueType, valueTypeName?: string, sensitive?: bool, default?: string, definition?: string, note?: string}
+	 * @since 32.0.0
+	 */
+	public function getKeyDetails(string $app, string $key): array {
+		$this->assertParams($app, $key);
+		try {
+			$details = $this->getDetails($app, $key);
+		} catch (AppConfigUnknownKeyException) {
+			$details = [
+				'app' => $app,
+				'key' => $key
+			];
+		}
+
+		/** @var Entry $lexiconEntry */
+		try {
+			$lazy = false;
+			$this->matchAndApplyLexiconDefinition($app, $key, $lazy, lexiconEntry: $lexiconEntry);
+		} catch (AppConfigTypeConflictException|AppConfigUnknownKeyException) {
+			// can be ignored
+		}
+
+		if ($lexiconEntry !== null) {
+			$details = array_merge($details, [
+				'lazy' => $lexiconEntry->isLazy(),
+				'valueType' => $lexiconEntry->getValueType(),
+				'valueTypeName' => $lexiconEntry->getValueType()->name,
+				'sensitive' => $lexiconEntry->isFlagged(self::FLAG_SENSITIVE),
+				'default' => $lexiconEntry->getDefault($this->presetManager->getLexiconPreset()),
+				'definition' => $lexiconEntry->getDefinition(),
+				'note' => $lexiconEntry->getNote(),
+			]);
+		}
+
+		return array_filter($details, static fn ($v): bool => ($v !== null));
+	}
+
 	/**
 	 * @param string $type
 	 *
@@ -1116,6 +1202,8 @@ class AppConfig implements IAppConfig {
 	 */
 	public function deleteKey(string $app, string $key): void {
 		$this->assertParams($app, $key);
+		$this->matchAndApplyLexiconDefinition($app, $key);
+
 		$qb = $this->connection->getQueryBuilder();
 		$qb->delete('appconfig')
 			->where($qb->expr()->eq('appid', $qb->createNamedParameter($app)))
@@ -1125,6 +1213,7 @@ class AppConfig implements IAppConfig {
 		unset($this->lazyCache[$app][$key]);
 		unset($this->fastCache[$app][$key]);
 		unset($this->valueTypes[$app][$key]);
+		$this->clearLocalCache();
 	}
 
 	/**
@@ -1149,17 +1238,19 @@ class AppConfig implements IAppConfig {
 	 *
 	 * @param bool $reload set to TRUE to refill cache instantly after clearing it
 	 *
+	 * @internal
 	 * @since 29.0.0
 	 */
 	public function clearCache(bool $reload = false): void {
 		$this->lazyLoaded = $this->fastLoaded = false;
-		$this->lazyCache = $this->fastCache = $this->valueTypes = [];
+		$this->lazyCache = $this->fastCache = $this->valueTypes = $this->configLexiconDetails = [];
+		$this->localCache?->remove(self::LOCAL_CACHE_KEY);
 
 		if (!$reload) {
 			return;
 		}
 
-		$this->loadConfigAll();
+		$this->loadConfig(lazy: true);
 	}
 
 
@@ -1220,117 +1311,84 @@ class AppConfig implements IAppConfig {
 		}
 	}
 
-	private function loadConfigAll(?string $app = null): void {
-		$this->loadConfig($app, null);
-	}
-
 	/**
 	 * Load normal config or config set as lazy loaded
 	 *
-	 * @param bool|null $lazy set to TRUE to load config set as lazy loaded, set to NULL to load all config
+	 * @param bool $lazy set to TRUE to also load config values set as lazy loaded
 	 */
-	private function loadConfig(?string $app = null, ?bool $lazy = false): void {
+	private function loadConfig(?string $app = null, bool $lazy = false): void {
 		if ($this->isLoaded($lazy)) {
 			return;
 		}
 
 		// if lazy is null or true, we debug log
-		if (($lazy ?? true) !== false && $app !== null) {
+		if ($lazy === true && $app !== null) {
 			$exception = new \RuntimeException('The loading of lazy AppConfig values have been triggered by app "' . $app . '"');
 			$this->logger->debug($exception->getMessage(), ['exception' => $exception, 'app' => $app]);
 		}
 
-		$qb = $this->connection->getQueryBuilder();
-		$qb->from('appconfig');
+		$loadLazyOnly = $lazy && $this->isLoaded();
 
-		/**
-		 * The use of $this->migrationCompleted is only needed to manage the
-		 * database during the upgrading process to nc29.
-		 */
-		if (!$this->migrationCompleted) {
-			$qb->select('appid', 'configkey', 'configvalue');
-		} else {
-			// we only need value from lazy when loadConfig does not specify it
-			$qb->select('appid', 'configkey', 'configvalue', 'type');
-
-			if ($lazy !== null) {
-				$qb->where($qb->expr()->eq('lazy', $qb->createNamedParameter($lazy ? 1 : 0, IQueryBuilder::PARAM_INT)));
-			} else {
-				$qb->addSelect('lazy');
+		/** @var array<mixed> */
+		$cacheContent = $this->localCache?->get(self::LOCAL_CACHE_KEY) ?? [];
+		$includesLazyValues = !empty($cacheContent) && !empty($cacheContent['lazyCache']);
+		if (!empty($cacheContent) && (!$lazy || $includesLazyValues)) {
+			$this->valueTypes = $cacheContent['valueTypes'];
+			$this->fastCache = $cacheContent['fastCache'];
+			$this->fastLoaded = !empty($this->fastCache);
+			if ($includesLazyValues) {
+				$this->lazyCache = $cacheContent['lazyCache'];
+				$this->lazyLoaded = !empty($this->lazyCache);
 			}
-		}
-
-		try {
-			$result = $qb->executeQuery();
-		} catch (DBException $e) {
-			/**
-			 * in case of issue with field name, it means that migration is not completed.
-			 * Falling back to a request without select on lazy.
-			 * This whole try/catch and the migrationCompleted variable can be removed in NC30.
-			 */
-			if ($e->getReason() !== DBException::REASON_INVALID_FIELD_NAME) {
-				throw $e;
-			}
-
-			$this->migrationCompleted = false;
-			$this->loadConfig($app, $lazy);
-
 			return;
 		}
 
+		// Otherwise no cache available and we need to fetch from database
+		$qb = $this->connection->getQueryBuilder();
+		$qb->from('appconfig')
+			->select('appid', 'configkey', 'configvalue', 'type');
+
+		if ($lazy === false) {
+			$qb->where($qb->expr()->eq('lazy', $qb->createNamedParameter(0, IQueryBuilder::PARAM_INT)));
+		} else {
+			if ($loadLazyOnly) {
+				$qb->where($qb->expr()->eq('lazy', $qb->createNamedParameter(1, IQueryBuilder::PARAM_INT)));
+			}
+			$qb->addSelect('lazy');
+		}
+
+		$result = $qb->executeQuery();
 		$rows = $result->fetchAll();
 		foreach ($rows as $row) {
 			// most of the time, 'lazy' is not in the select because its value is already known
-			if (($row['lazy'] ?? ($lazy ?? 0) ? 1 : 0) === 1) {
+			if ($lazy && ((int)$row['lazy']) === 1) {
 				$this->lazyCache[$row['appid']][$row['configkey']] = $row['configvalue'] ?? '';
 			} else {
 				$this->fastCache[$row['appid']][$row['configkey']] = $row['configvalue'] ?? '';
 			}
 			$this->valueTypes[$row['appid']][$row['configkey']] = (int)($row['type'] ?? 0);
 		}
+
 		$result->closeCursor();
-		$this->setAsLoaded($lazy);
+		$this->localCache?->set(
+			self::LOCAL_CACHE_KEY,
+			[
+				'fastCache' => $this->fastCache,
+				'lazyCache' => $this->lazyCache,
+				'valueTypes' => $this->valueTypes,
+			],
+			self::LOCAL_CACHE_TTL,
+		);
+
+		$this->fastLoaded = true;
+		$this->lazyLoaded = $lazy;
 	}
 
 	/**
-	 * if $lazy is:
-	 *  - false: will returns true if fast config is loaded
-	 *  - true : will returns true if lazy config is loaded
-	 *  - null : will returns true if both config are loaded
-	 *
-	 * @param bool $lazy
-	 *
-	 * @return bool
+	 * @param bool $lazy - If set to true then also check if lazy values are loaded
 	 */
-	private function isLoaded(?bool $lazy): bool {
-		if ($lazy === null) {
-			return $this->lazyLoaded && $this->fastLoaded;
-		}
-
-		return $lazy ? $this->lazyLoaded : $this->fastLoaded;
-	}
-
-	/**
-	 * if $lazy is:
-	 * - false: set fast config as loaded
-	 * - true : set lazy config as loaded
-	 * - null : set both config as loaded
-	 *
-	 * @param bool $lazy
-	 */
-	private function setAsLoaded(?bool $lazy): void {
-		if ($lazy === null) {
-			$this->fastLoaded = true;
-			$this->lazyLoaded = true;
-
-			return;
-		}
-
-		if ($lazy) {
-			$this->lazyLoaded = true;
-		} else {
-			$this->fastLoaded = true;
-		}
+	private function isLoaded(bool $lazy = false): bool {
+		return $this->fastLoaded && (!$lazy || $this->lazyLoaded);
 	}
 
 	/**
@@ -1338,7 +1396,7 @@ class AppConfig implements IAppConfig {
 	 *
 	 * @param string $app app
 	 * @param string $key key
-	 * @param string $default = null, default value if the key does not exist
+	 * @param string $default - Default value if the key does not exist
 	 *
 	 * @return string the value or $default
 	 * @deprecated 29.0.0 use getValue*()
@@ -1346,8 +1404,9 @@ class AppConfig implements IAppConfig {
 	 * This function gets a value from the appconfig table. If the key does
 	 * not exist the default value will be returned
 	 */
-	public function getValue($app, $key, $default = null) {
+	public function getValue($app, $key, $default = '') {
 		$this->loadConfig($app);
+		$this->matchAndApplyLexiconDefinition($app, $key);
 
 		return $this->fastCache[$app][$key] ?? $default;
 	}
@@ -1372,7 +1431,7 @@ class AppConfig implements IAppConfig {
 		 * or enabled (lazy=lazy-2)
 		 *
 		 * this solution would remove the loading of config values from disabled app
-		 * unless calling the method {@see loadConfigAll()}
+		 * unless calling the method.
 		 */
 		return $this->setTypedValue($app, $key, (string)$value, false, self::VALUE_MIXED);
 	}
@@ -1427,7 +1486,7 @@ class AppConfig implements IAppConfig {
 		foreach ($values as $key => $value) {
 			try {
 				$type = $this->getValueType($app, $key, $lazy);
-			} catch (AppConfigUnknownKeyException $e) {
+			} catch (AppConfigUnknownKeyException) {
 				continue;
 			}
 
@@ -1611,7 +1670,8 @@ class AppConfig implements IAppConfig {
 	}
 
 	/**
-	 * match and apply current use of config values with defined lexicon
+	 * Match and apply current use of config values with defined lexicon.
+	 * Set $lazy to NULL only if only interested into checking that $key is alias.
 	 *
 	 * @throws AppConfigUnknownKeyException
 	 * @throws AppConfigTypeConflictException
@@ -1619,10 +1679,11 @@ class AppConfig implements IAppConfig {
 	 */
 	private function matchAndApplyLexiconDefinition(
 		string $app,
-		string $key,
-		bool &$lazy,
-		int &$type,
-		string &$default = '',
+		string &$key,
+		?bool &$lazy = null,
+		int &$type = self::VALUE_MIXED,
+		?string &$default = null,
+		?Entry &$lexiconEntry = null,
 	): bool {
 		if (in_array($key,
 			[
@@ -1633,30 +1694,41 @@ class AppConfig implements IAppConfig {
 			return true; // we don't break stuff for this list of config keys.
 		}
 		$configDetails = $this->getConfigDetailsFromLexicon($app);
-		if (!array_key_exists($key, $configDetails['entries'])) {
-			return $this->applyLexiconStrictness(
-				$configDetails['strictness'],
-				'The app config key ' . $app . '/' . $key . ' is not defined in the config lexicon'
-			);
+		if (array_key_exists($key, $configDetails['aliases']) && !$this->ignoreLexiconAliases) {
+			// in case '$rename' is set in ConfigLexiconEntry, we use the new config key
+			$key = $configDetails['aliases'][$key];
 		}
 
-		/** @var ConfigLexiconEntry $configValue */
-		$configValue = $configDetails['entries'][$key];
+		if (!array_key_exists($key, $configDetails['entries'])) {
+			return $this->applyLexiconStrictness($configDetails['strictness'], $app . '/' . $key);
+		}
+
+		// if lazy is NULL, we ignore all check on the type/lazyness/default from Lexicon
+		if ($lazy === null) {
+			return true;
+		}
+
+		/** @var Entry $lexiconEntry */
+		$lexiconEntry = $configDetails['entries'][$key];
 		$type &= ~self::VALUE_SENSITIVE;
 
-		$appConfigValueType = $configValue->getValueType()->toAppConfigFlag();
+		$appConfigValueType = $lexiconEntry->getValueType()->toAppConfigFlag();
 		if ($type === self::VALUE_MIXED) {
 			$type = $appConfigValueType; // we overwrite if value was requested as mixed
 		} elseif ($appConfigValueType !== $type) {
 			throw new AppConfigTypeConflictException('The app config key ' . $app . '/' . $key . ' is typed incorrectly in relation to the config lexicon');
 		}
 
-		$lazy = $configValue->isLazy();
-		$default = $configValue->getDefault() ?? $default; // default from Lexicon got priority
-		if ($configValue->isFlagged(self::FLAG_SENSITIVE)) {
+		$lazy = $lexiconEntry->isLazy();
+		// only look for default if needed, default from Lexicon got priority
+		if ($default !== null) {
+			$default = $lexiconEntry->getDefault($this->presetManager->getLexiconPreset()) ?? $default;
+		}
+
+		if ($lexiconEntry->isFlagged(self::FLAG_SENSITIVE)) {
 			$type |= self::VALUE_SENSITIVE;
 		}
-		if ($configValue->isDeprecated()) {
+		if ($lexiconEntry->isDeprecated()) {
 			$this->logger->notice('App config key ' . $app . '/' . $key . ' is set as deprecated.');
 		}
 
@@ -1666,29 +1738,33 @@ class AppConfig implements IAppConfig {
 	/**
 	 * manage ConfigLexicon behavior based on strictness set in IConfigLexicon
 	 *
-	 * @param ConfigLexiconStrictness|null $strictness
+	 * @param Strictness|null $strictness
 	 * @param string $line
 	 *
 	 * @return bool TRUE if conflict can be fully ignored, FALSE if action should be not performed
 	 * @throws AppConfigUnknownKeyException if strictness implies exception
-	 * @see IConfigLexicon::getStrictness()
+	 * @see \OCP\Config\Lexicon\ILexicon::getStrictness()
 	 */
-	private function applyLexiconStrictness(
-		?ConfigLexiconStrictness $strictness,
-		string $line = '',
-	): bool {
+	private function applyLexiconStrictness(?Strictness $strictness, string $configAppKey): bool {
 		if ($strictness === null) {
 			return true;
 		}
 
+		$line = 'The app config key ' . $configAppKey . ' is not defined in the config lexicon';
 		switch ($strictness) {
-			case ConfigLexiconStrictness::IGNORE:
+			case Strictness::IGNORE:
 				return true;
-			case ConfigLexiconStrictness::NOTICE:
-				$this->logger->notice($line);
+			case Strictness::NOTICE:
+				if (!in_array($configAppKey, $this->strictnessApplied, true)) {
+					$this->strictnessApplied[] = $configAppKey;
+					$this->logger->notice($line);
+				}
 				return true;
-			case ConfigLexiconStrictness::WARNING:
-				$this->logger->warning($line);
+			case Strictness::WARNING:
+				if (!in_array($configAppKey, $this->strictnessApplied, true)) {
+					$this->strictnessApplied[] = $configAppKey;
+					$this->logger->warning($line);
+				}
 				return false;
 		}
 
@@ -1699,24 +1775,73 @@ class AppConfig implements IAppConfig {
 	 * extract details from registered $appId's config lexicon
 	 *
 	 * @param string $appId
+	 * @internal
 	 *
-	 * @return array{entries: array<array-key, ConfigLexiconEntry>, strictness: ConfigLexiconStrictness}
+	 * @return array{entries: array<string, Entry>, aliases: array<string, string>, strictness: Strictness}
 	 */
-	private function getConfigDetailsFromLexicon(string $appId): array {
+	public function getConfigDetailsFromLexicon(string $appId): array {
 		if (!array_key_exists($appId, $this->configLexiconDetails)) {
-			$entries = [];
+			$entries = $aliases = [];
 			$bootstrapCoordinator = \OCP\Server::get(Coordinator::class);
 			$configLexicon = $bootstrapCoordinator->getRegistrationContext()?->getConfigLexicon($appId);
 			foreach ($configLexicon?->getAppConfigs() ?? [] as $configEntry) {
 				$entries[$configEntry->getKey()] = $configEntry;
+				$newName = $configEntry->getRename();
+				if ($newName !== null) {
+					$aliases[$newName] = $configEntry->getKey();
+				}
 			}
 
 			$this->configLexiconDetails[$appId] = [
 				'entries' => $entries,
-				'strictness' => $configLexicon?->getStrictness() ?? ConfigLexiconStrictness::IGNORE
+				'aliases' => $aliases,
+				'strictness' => $configLexicon?->getStrictness() ?? Strictness::IGNORE
 			];
 		}
 
 		return $this->configLexiconDetails[$appId];
 	}
+
+	/**
+	 * get Lexicon Entry using appId and config key entry
+	 *
+	 * @return Entry|null NULL if entry does not exist in app's Lexicon
+	 * @internal
+	 */
+	public function getLexiconEntry(string $appId, string $key): ?Entry {
+		return $this->getConfigDetailsFromLexicon($appId)['entries'][$key] ?? null;
+	}
+
+	/**
+	 * if set to TRUE, ignore aliases defined in Config Lexicon during the use of the methods of this class
+	 *
+	 * @internal
+	 */
+	public function ignoreLexiconAliases(bool $ignore): void {
+		$this->ignoreLexiconAliases = $ignore;
+	}
+
+	/**
+	 * Returns the installed versions of all apps
+	 *
+	 * @return array<string, string>
+	 */
+	public function getAppInstalledVersions(bool $onlyEnabled = false): array {
+		if ($this->appVersionsCache === null) {
+			/** @var array<string, string> */
+			$this->appVersionsCache = $this->searchValues('installed_version', false, IAppConfig::VALUE_STRING);
+		}
+		if ($onlyEnabled) {
+			return array_filter(
+				$this->appVersionsCache,
+				fn (string $app): bool => $this->getValueString($app, 'enabled', 'no') !== 'no',
+				ARRAY_FILTER_USE_KEY
+			);
+		}
+		return $this->appVersionsCache;
+	}
+
+	private function clearLocalCache(): void {
+		$this->localCache?->remove(self::LOCAL_CACHE_KEY);
+	}
 }
